import { s as subscribe, g as get_store_value } from "./utils.js";
import { c as create_ssr_component, o as onDestroy, a as add_attribute, e as escape } from "./ssr.js";
import { p as page } from "./stores.js";
import { g as getBestThumbnail } from "./images.js";
import "human-number";
import { Capacitor } from "@capacitor/core";
import "@capacitor/screen-orientation";
import "@capacitor/status-bar";
import "@hugotomazi/capacitor-navigation-bar";
import { AudioPlayer } from "@mediagrid/capacitor-native-audio";
import "sponsorblock-api";
import "./runtime.js";
import { s as saveVideoProgress, o as deleteVideoProgress } from "./index.js";
import "./client.js";
import "he";
import { q as playerAutoPlayStore, t as playerAlwaysLoopStore, u as silenceSkipperStore, p as playerProxyVideosStore, g as instanceStore, e as playerSavePlaybackPositionStore, v as synciousStore, o as synciousInstanceStore, b as authStore } from "./store.js";
import "./beer.min.js";
const Player = create_ssr_component(($$result, $$props, $$bindings, slots) => {
  let $$unsubscribe_page;
  let $playerAutoPlayStore, $$unsubscribe_playerAutoPlayStore;
  let $playerAlwaysLoopStore, $$unsubscribe_playerAlwaysLoopStore;
  $$unsubscribe_page = subscribe(page, (value) => value);
  $$unsubscribe_playerAutoPlayStore = subscribe(playerAutoPlayStore, (value) => $playerAutoPlayStore = value);
  $$unsubscribe_playerAlwaysLoopStore = subscribe(playerAlwaysLoopStore, (value) => $playerAlwaysLoopStore = value);
  let { data } = $$props;
  let { audioMode = false } = $$props;
  let { player } = $$props;
  let { isSyncing = false } = $$props;
  let { isEmbed = false } = $$props;
  let { segments = [] } = $$props;
  let src = [];
  let snackBarAlert = "";
  let userVideoSpeed = 1;
  let silenceIsFastForwarding = false;
  let silenceSkipperInterval;
  function loadTimeFromUrl(page2) {
    if (player) {
      const timeGivenUrl = page2.url.searchParams.get("time");
      if (timeGivenUrl && !isNaN(parseFloat(timeGivenUrl))) {
        player.currentTime = Number(timeGivenUrl);
        return true;
      }
    }
    return false;
  }
  page.subscribe((pageUpdate) => loadTimeFromUrl(pageUpdate));
  let initStoreSilence = true;
  silenceSkipperStore.subscribe((value) => {
    if (initStoreSilence) {
      initStoreSilence = false;
      return;
    }
    if (typeof silenceSkipperInterval !== "undefined") {
      clearInterval(silenceSkipperInterval);
    }
    if (value) {
      initSilenceSkipper();
    }
  });
  get_store_value(playerProxyVideosStore);
  function fastForwardToSound(videoElement, threshold = 0.01, checkInterval = 100, fastForwardRate = 4) {
    if (!(videoElement instanceof HTMLMediaElement)) {
      console.error("Provided element is not a valid HTMLMediaElement");
      return;
    }
    const audioContext = new AudioContext();
    const source = audioContext.createMediaElementSource(videoElement);
    const analyser = audioContext.createAnalyser();
    source.connect(analyser);
    analyser.connect(audioContext.destination);
    analyser.fftSize = 256;
    const dataArray = new Uint8Array(analyser.frequencyBinCount);
    const checkForSound = () => {
      analyser.getByteFrequencyData(dataArray);
      const averageVolume = dataArray.reduce((a, b) => a + b, 0) / dataArray.length;
      const volume = averageVolume / 255;
      if (volume < threshold) {
        if (!silenceIsFastForwarding) {
          videoElement.playbackRate = fastForwardRate;
          silenceIsFastForwarding = true;
        }
      } else {
        if (silenceIsFastForwarding) {
          videoElement.playbackRate = userVideoSpeed;
          silenceIsFastForwarding = false;
        }
      }
    };
    silenceSkipperInterval = setInterval(checkForSound, checkInterval);
  }
  function initSilenceSkipper() {
    const videoContainer = document.getElementById("video");
    const videoElement = videoContainer.querySelector("video");
    fastForwardToSound(videoElement);
  }
  function savePlayerPos() {
    if (data.video.hlsUrl) return;
    if (get_store_value(playerSavePlaybackPositionStore) && player && player.currentTime) {
      if (player.currentTime < player.duration - 10 && player.currentTime > 10) {
        try {
          localStorage.setItem(`v_${data.video.videoId}`, player.currentTime.toString());
        } catch {
        }
        if (get_store_value(synciousStore) && get_store_value(synciousInstanceStore) && get_store_value(authStore)) {
          saveVideoProgress(data.video.videoId, player.currentTime);
        }
      } else {
        try {
          localStorage.removeItem(`v_${data.video.videoId}`);
        } catch {
        }
        if (get_store_value(synciousStore) && get_store_value(synciousInstanceStore) && get_store_value(authStore)) {
          deleteVideoProgress(data.video.videoId);
        }
      }
    }
  }
  onDestroy(async () => {
    if (Capacitor.getPlatform() === "android") {
      await AudioPlayer.destroy({ audioId: data.video.videoId });
    }
    if (typeof silenceSkipperInterval !== "undefined") {
      clearInterval(silenceSkipperInterval);
    }
    try {
      savePlayerPos();
    } catch (error) {
    }
    await player.pause();
    player.destroy();
  });
  if ($$props.data === void 0 && $$bindings.data && data !== void 0) $$bindings.data(data);
  if ($$props.audioMode === void 0 && $$bindings.audioMode && audioMode !== void 0) $$bindings.audioMode(audioMode);
  if ($$props.player === void 0 && $$bindings.player && player !== void 0) $$bindings.player(player);
  if ($$props.isSyncing === void 0 && $$bindings.isSyncing && isSyncing !== void 0) $$bindings.isSyncing(isSyncing);
  if ($$props.isEmbed === void 0 && $$bindings.isEmbed && isEmbed !== void 0) $$bindings.isEmbed(isEmbed);
  if ($$props.segments === void 0 && $$bindings.segments && segments !== void 0) $$bindings.segments(segments);
  $$unsubscribe_page();
  $$unsubscribe_playerAutoPlayStore();
  $$unsubscribe_playerAlwaysLoopStore();
  return `${audioMode ? `<div style="margin-top: 40vh;"></div>` : ``} <media-player id="video" ${$playerAutoPlayStore && !isSyncing ? "autoplay" : ""} ${$playerAlwaysLoopStore ? "loop" : ""}${add_attribute("title", data.video.title, 0)}${add_attribute("streamtype", "on-demand", 0)}${add_attribute("viewtype", audioMode ? "audio" : "video", 0)} keep-alive${add_attribute("src", src, 0)}${add_attribute("this", player, 0)}><media-provider>${!audioMode ? `<media-poster class="vds-poster"${add_attribute("src", getBestThumbnail(data.video.videoThumbnails, 1251, 781), 0)}></media-poster>` : ``}</media-provider> <media-audio-layout></media-audio-layout> ${data.video.storyboards && data.video.storyboards.length > 3 ? `<media-video-layout${add_attribute("thumbnails", `${get_store_value(instanceStore)}${data.video.storyboards[3].url}`, 0)}></media-video-layout>` : `<media-video-layout></media-video-layout>`}</media-player> ${!isEmbed ? `<div class="snackbar" id="snackbar-alert"><span class="bold" style="text-transform: capitalize;">${escape(snackBarAlert)}</span></div>` : ``}`;
});
export {
  Player as P
};
