import { g as get_store_value, s as subscribe, d as null_to_empty, e as set_store_value } from "../../../chunks/utils.js";
import { c as create_ssr_component, a as add_attribute, e as escape, f as createEventDispatcher, b as each, v as validate_component, o as onDestroy, g as add_classes } from "../../../chunks/ssr.js";
import { g as goto } from "../../../chunks/client.js";
import { p as page, n as navigating } from "../../../chunks/stores.js";
import { Capacitor, registerPlugin } from "@capacitor/core";
import { E as interfaceAmoledTheme, F as darkModeStore, G as themeColorStore, D as miniPlayerSrcStore, p as playerProxyVideosStore, H as searchHistoryStore, I as interfaceSearchHistoryEnabled, J as interfaceSearchSuggestionsStore, v as synciousStore, o as synciousInstanceStore, g as instanceStore, K as deArrowTitlesOnly, L as deArrowEnabledStore, M as deArrowInstanceStore, N as deArrowThumbnailInstanceStore, c as interfaceDisplayThumbnailAvatars, i as interfaceLowBandwidthMode, O as interfacePreviewVideoOnHoverStore, x as interfaceAutoExpandDesc, y as interfaceAutoExpandComments, l as interfaceRegionStore, f as interfaceForceCase, h as interfaceDefaultPage, b as authStore, P as playerDefaultLanguage, C as playerMiniPlayerStore, q as playerAutoPlayStore, t as playerAlwaysLoopStore, Q as playerAndroidBgPlayer, R as playerAndroidLockOrientation, e as playerSavePlaybackPositionStore, A as playerListenByDefaultStore, z as playerTheatreModeByDefaultStore, w as playerAutoplayNextByDefaultStore, u as silenceSkipperStore, m as playerYouTubeJsAlways, n as playerYouTubeJsFallback, j as returnYtDislikesStore, r as returnYTDislikesInstanceStore, S as sponsorBlockStore, T as sponsorBlockDisplayToastStore, U as sponsorBlockTimelineStore, V as sponsorBlockCategoriesStore, W as sponsorBlockUrlStore, d as syncPartyPeerStore, s as syncPartyConnectionsStore, X as showWarningStore, a as activePageStore } from "../../../chunks/store.js";
import "human-number";
import "bgutils-js";
import "youtubei.js";
import { r as rt } from "../../../chunks/beer.min.js";
import { StatusBar, Style } from "@capacitor/status-bar";
import { NavigationBar } from "@hugotomazi/capacitor-navigation-bar";
import { t as tick } from "../../../chunks/scheduler.js";
import { p as proxyVideoUrl } from "../../../chunks/misc.js";
import { P as PageLoading } from "../../../chunks/PageLoading.js";
import "mousetrap";
import { $ as $format } from "../../../chunks/runtime.js";
import ISO6391 from "iso-639-1";
import "he";
import { l as letterCase, t as titleCases, a as titleCase } from "../../../chunks/letterCasing.js";
import "@capacitor/clipboard";
import { iso31661 } from "iso-3166";
import { g as getPages } from "../../../chunks/navPages.js";
import { T as Thumbnail } from "../../../chunks/Thumbnail.js";
import { App } from "@capacitor/app";
import "@capacitor/browser";
import "material-dynamic-colors";
if (Capacitor.getPlatform() === "android") {
  const originalFetch = window.fetch;
  const corsProxyUrl = "http://localhost:3000/";
  window.fetch = async (requestInput, requestOptions) => {
    let requestUrl;
    if (typeof requestInput === "string") {
      requestUrl = requestInput;
    } else if ("url" in requestInput) {
      requestUrl = requestInput.url;
      requestOptions = {
        body: requestInput.body,
        cache: requestInput.cache,
        credentials: requestInput.credentials,
        headers: requestInput.headers,
        method: requestInput.method,
        mode: requestInput.mode,
        redirect: requestInput.redirect,
        referrer: requestInput.referrer,
        signal: requestInput.signal
      };
      if (requestOptions.body && requestOptions.body instanceof ReadableStream) {
        requestOptions.duplex = "half";
      }
    } else {
      requestUrl = requestInput.toString();
    }
    if (!requestUrl.startsWith(corsProxyUrl) && !requestUrl.startsWith("/") && !requestUrl.startsWith("blob:")) {
      requestInput = corsProxyUrl + requestUrl;
    }
    return originalFetch(requestInput, requestOptions);
  };
  const currentOrigin = window.location.protocol + "//" + window.location.host;
  const originalXhrOpen = XMLHttpRequest.prototype.open;
  XMLHttpRequest.prototype.open = function(...args) {
    const targetOriginMatch = /^https?:\/\/([^\/]+)/i.exec(args[1]);
    if (targetOriginMatch && targetOriginMatch[0].toLowerCase() !== currentOrigin) {
      args[1] = corsProxyUrl + args[1];
    }
    return originalXhrOpen.apply(this, args);
  };
  setTimeout(() => goto("/", { replaceState: true }), 10);
}
registerPlugin("ColorTheme");
async function getDynamicTheme(mode) {
  const givenSettings = await rt("theme");
  const themes = givenSettings[rt("mode")];
  let themeVars = {};
  themes.split(";").forEach((keyVar) => {
    let [key, value] = keyVar.split(":");
    themeVars[key] = value;
  });
  return themeVars;
}
async function setStatusBarColor() {
  if (Capacitor.getPlatform() === "android") {
    await tick();
    const surfaceColor = get_store_value(interfaceAmoledTheme) ? "#000000" : (await getDynamicTheme())["--surface-container"];
    await StatusBar.setBackgroundColor({
      color: surfaceColor
    });
    await NavigationBar.setColor({
      color: surfaceColor,
      darkButtons: !get_store_value(darkModeStore)
    });
    await NavigationBar.show();
    if (get_store_value(darkModeStore)) {
      await StatusBar.setStyle({ style: Style.Dark });
    } else {
      await StatusBar.setStyle({ style: Style.Light });
    }
  }
}
function setAmoledTheme() {
  const isAmoled = get_store_value(interfaceAmoledTheme);
  const isDark = get_store_value(darkModeStore);
  if (isAmoled && isDark) {
    const rootVars = [
      "--surface-container",
      "--surface",
      "--surface-container-lowest",
      "--surface-container-low",
      "--surface-container-high",
      "--surface-container-highest"
    ];
    rootVars.forEach((varName) => {
      document.body.style.setProperty(varName, "#000");
    });
  } else {
    setTheme();
  }
}
function setTheme() {
  const isDark = get_store_value(darkModeStore);
  if (isDark === null) {
    if (window.matchMedia && window.matchMedia("(prefers-color-scheme: dark)").matches) {
      darkModeStore.set(true);
      rt("mode", "dark");
    } else {
      darkModeStore.set(false);
      rt("mode", "light");
    }
  } else {
    if (isDark) {
      rt("mode", "dark");
    } else {
      rt("mode", "light");
    }
  }
}
const Logo = create_ssr_component(($$result, $$props, $$bindings, slots) => {
  let { classes = "" } = $$props;
  let fillColor = "";
  async function setFill() {
    fillColor = (await getDynamicTheme())["--primary"];
  }
  darkModeStore.subscribe(async () => {
    await setFill();
  });
  themeColorStore.subscribe(async () => {
    await setFill();
  });
  if ($$props.classes === void 0 && $$bindings.classes && classes !== void 0) $$bindings.classes(classes);
  return `<svg version="1.1" id="svg1"${add_attribute("class", classes, 0)} height="100%" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" viewBox="50.17 104.37 109.67 88.27"><defs id="defs1"></defs><g id="layer1"><g id="g6" transform="matrix(1.0140222,0,0,1.0140222,-1.4722742,-56.323482)"><g id="g1" transform="matrix(-1,0,0,1,201.63735,-7.4456246e-6)"><g id="g5"><path id="path5"${add_attribute("style", `color:#000000;fill:${fillColor};stroke-linecap:square;-inkscape-stroke:none;paint-order:stroke markers fill`, 0)} d="m 114.65661,173.40906 -1.29294,4.82606 h -5.2e-4 l -44.404523,11.89798 32.504993,32.50551 10e-4,0.001 -6.12107,22.84563 -26.381853,-26.38185 -26.381335,-26.38134 36.03811,-9.65625 z m -4.28191,15.97939 -5.37486,20.05872 -0.54622,2.03915 -16.176276,-16.17679 z"></path><path${add_attribute("style", `color:#000000;fill:${fillColor};stroke-linecap:square;-inkscape-stroke:none;paint-order:stroke markers fill`, 0)} d="M 131.38171,245.48534 105,219.10365 l -26.381696,-26.3817 36.038076,-9.65637 36.03807,-9.65638 -9.65637,36.03807 z" id="path3"></path></g></g><circle${add_attribute("style", `opacity:1;fill:${fillColor};fill-opacity:1;stroke:none;stroke-width:10.8326;stroke-linecap:square;stroke-dasharray:none;stroke-opacity:1;paint-order:stroke markers fill`, 0)} id="path6" cx="86.980743" cy="163.40662" r="4.9097047"></circle></g></g></svg>`;
});
const css$3 = {
  code: "nav.svelte-zyd8lx.svelte-zyd8lx{display:flex;background-color:transparent;justify-content:end;align-items:flex-end}article.svelte-zyd8lx.svelte-zyd8lx{display:flex;flex-direction:column;align-items:flex-end}nav.svelte-zyd8lx video.svelte-zyd8lx{height:180px;width:auto}.flex-container.svelte-zyd8lx.svelte-zyd8lx{flex:1;overflow:hidden}.truncate.svelte-zyd8lx.svelte-zyd8lx{white-space:nowrap;overflow:hidden;text-overflow:ellipsis;max-width:270px}@media screen and (max-width: 590px){nav.bottom.svelte-zyd8lx.svelte-zyd8lx{bottom:100px !important}nav.svelte-zyd8lx.svelte-zyd8lx{flex-direction:initial;background-color:initial;justify-content:initial;align-items:initial}article.svelte-zyd8lx.svelte-zyd8lx{align-items:start;width:100%;flex-direction:row;padding:0 !important;justify-content:center}nav.svelte-zyd8lx video.svelte-zyd8lx{height:100%;margin-left:10px}.flex-container.svelte-zyd8lx.svelte-zyd8lx{max-width:100%}}",
  map: '{"version":3,"file":"MiniPlayer.svelte","sources":["MiniPlayer.svelte"],"sourcesContent":["<script lang=\\"ts\\">import { goto } from \\"$app/navigation\\";\\nimport { get } from \\"svelte/store\\";\\nimport { proxyVideoUrl } from \\"../misc\\";\\nimport { miniPlayerSrcStore, playerProxyVideosStore } from \\"../store\\";\\nlet currentTime = 0;\\nfunction setTime() {\\n  const player = document.getElementById(\\"video\\") || null;\\n  if (player && $miniPlayerSrcStore) {\\n    try {\\n      const vidstackDetails = localStorage.getItem(\\"video-player\\");\\n      if (vidstackDetails) {\\n        const vidstackDetailsParsed = JSON.parse(vidstackDetails);\\n        if (\\"volume\\" in vidstackDetailsParsed) player.volume = vidstackDetailsParsed.volume;\\n      }\\n    } catch {\\n    }\\n    player.currentTime = $miniPlayerSrcStore.time;\\n  }\\n  if (player.volume === 0) {\\n    player.volume = 1;\\n  }\\n}\\n<\/script>\\n\\n{#if $miniPlayerSrcStore && $miniPlayerSrcStore.video.formatStreams.length > 0}\\n\\t<nav class=\\"bottom no-padding\\">\\n\\t\\t<article class=\\"surface-bright\\">\\n\\t\\t\\t<button on:click={() => miniPlayerSrcStore.set(null)} class=\\"s circle transparent no-margin\\">\\n\\t\\t\\t\\t<i>close</i>\\n\\t\\t\\t</button>\\n\\t\\t\\t<div class=\\"flex-container\\">\\n\\t\\t\\t\\t<div style=\\"display: flex;\\">\\n\\t\\t\\t\\t\\t<p class=\\"bold truncate\\">\\n\\t\\t\\t\\t\\t\\t{$miniPlayerSrcStore.video.title}\\n\\t\\t\\t\\t\\t</p>\\n\\t\\t\\t\\t\\t<button\\n\\t\\t\\t\\t\\t\\ton:click={() => miniPlayerSrcStore.set(null)}\\n\\t\\t\\t\\t\\t\\tclass=\\"m l circle transparent no-margin\\"\\n\\t\\t\\t\\t\\t>\\n\\t\\t\\t\\t\\t\\t<i>close</i>\\n\\t\\t\\t\\t\\t</button>\\n\\t\\t\\t\\t</div>\\n\\t\\t\\t\\t<progress class=\\"s\\" value={currentTime} max={$miniPlayerSrcStore.video.lengthSeconds}\\n\\t\\t\\t\\t></progress>\\n\\t\\t\\t</div>\\n\\t\\t\\t<video\\n\\t\\t\\t\\ton:click={() => {\\n\\t\\t\\t\\t\\tgoto(`/watch/${$miniPlayerSrcStore.video.videoId}?time=${currentTime}`);\\n\\t\\t\\t\\t\\tminiPlayerSrcStore.set(null);\\n\\t\\t\\t\\t}}\\n\\t\\t\\t\\tid=\\"video\\"\\n\\t\\t\\t\\tstyle=\\"cursor: pointer;\\"\\n\\t\\t\\t\\tbind:currentTime\\n\\t\\t\\t\\ton:loadedmetadata={setTime}\\n\\t\\t\\t\\tcontrols={false}\\n\\t\\t\\t\\tautoplay\\n\\t\\t\\t\\tsrc={get(playerProxyVideosStore)\\n\\t\\t\\t\\t\\t? proxyVideoUrl($miniPlayerSrcStore.video.formatStreams[0].url)\\n\\t\\t\\t\\t\\t: $miniPlayerSrcStore.video.formatStreams[0].url}\\n\\t\\t\\t>\\n\\t\\t\\t</video>\\n\\t\\t</article>\\n\\t</nav>\\n{/if}\\n\\n<style>\\n\\tnav {\\n\\t\\tdisplay: flex;\\n\\t\\tbackground-color: transparent;\\n\\t\\tjustify-content: end;\\n\\t\\talign-items: flex-end;\\n\\t}\\n\\n\\tarticle {\\n\\t\\tdisplay: flex;\\n\\t\\tflex-direction: column;\\n\\t\\talign-items: flex-end;\\n\\t}\\n\\n\\tnav video {\\n\\t\\theight: 180px;\\n\\t\\twidth: auto;\\n\\t}\\n\\n\\t.flex-container {\\n\\t\\tflex: 1;\\n\\t\\toverflow: hidden;\\n\\t}\\n\\n\\t.truncate {\\n\\t\\twhite-space: nowrap;\\n\\t\\toverflow: hidden;\\n\\t\\ttext-overflow: ellipsis;\\n\\t\\tmax-width: 270px;\\n\\t}\\n\\n\\t@media screen and (max-width: 590px) {\\n\\t\\tnav.bottom {\\n\\t\\t\\tbottom: 100px !important;\\n\\t\\t}\\n\\n\\t\\tnav {\\n\\t\\t\\tflex-direction: initial;\\n\\t\\t\\tbackground-color: initial;\\n\\t\\t\\tjustify-content: initial;\\n\\t\\t\\talign-items: initial;\\n\\t\\t}\\n\\n\\t\\tarticle {\\n\\t\\t\\talign-items: start;\\n\\t\\t\\twidth: 100%;\\n\\t\\t\\tflex-direction: row;\\n\\t\\t\\tpadding: 0 !important;\\n\\t\\t\\tjustify-content: center;\\n\\t\\t}\\n\\n\\t\\tnav video {\\n\\t\\t\\theight: 100%;\\n\\t\\t\\tmargin-left: 10px;\\n\\t\\t}\\n\\n\\t\\t.flex-container {\\n\\t\\t\\tmax-width: 100%;\\n\\t\\t}\\n\\t}\\n</style>\\n"],"names":[],"mappings":"AAkEC,+BAAI,CACH,OAAO,CAAE,IAAI,CACb,gBAAgB,CAAE,WAAW,CAC7B,eAAe,CAAE,GAAG,CACpB,WAAW,CAAE,QACd,CAEA,mCAAQ,CACP,OAAO,CAAE,IAAI,CACb,cAAc,CAAE,MAAM,CACtB,WAAW,CAAE,QACd,CAEA,iBAAG,CAAC,mBAAM,CACT,MAAM,CAAE,KAAK,CACb,KAAK,CAAE,IACR,CAEA,2CAAgB,CACf,IAAI,CAAE,CAAC,CACP,QAAQ,CAAE,MACX,CAEA,qCAAU,CACT,WAAW,CAAE,MAAM,CACnB,QAAQ,CAAE,MAAM,CAChB,aAAa,CAAE,QAAQ,CACvB,SAAS,CAAE,KACZ,CAEA,OAAO,MAAM,CAAC,GAAG,CAAC,YAAY,KAAK,CAAE,CACpC,GAAG,mCAAQ,CACV,MAAM,CAAE,KAAK,CAAC,UACf,CAEA,+BAAI,CACH,cAAc,CAAE,OAAO,CACvB,gBAAgB,CAAE,OAAO,CACzB,eAAe,CAAE,OAAO,CACxB,WAAW,CAAE,OACd,CAEA,mCAAQ,CACP,WAAW,CAAE,KAAK,CAClB,KAAK,CAAE,IAAI,CACX,cAAc,CAAE,GAAG,CACnB,OAAO,CAAE,CAAC,CAAC,UAAU,CACrB,eAAe,CAAE,MAClB,CAEA,iBAAG,CAAC,mBAAM,CACT,MAAM,CAAE,IAAI,CACZ,WAAW,CAAE,IACd,CAEA,2CAAgB,CACf,SAAS,CAAE,IACZ,CACD"}'
};
const MiniPlayer = create_ssr_component(($$result, $$props, $$bindings, slots) => {
  let $miniPlayerSrcStore, $$unsubscribe_miniPlayerSrcStore;
  $$unsubscribe_miniPlayerSrcStore = subscribe(miniPlayerSrcStore, (value) => $miniPlayerSrcStore = value);
  let currentTime = 0;
  $$result.css.add(css$3);
  $$unsubscribe_miniPlayerSrcStore();
  return `${$miniPlayerSrcStore && $miniPlayerSrcStore.video.formatStreams.length > 0 ? `<nav class="bottom no-padding svelte-zyd8lx"><article class="surface-bright svelte-zyd8lx"><button class="s circle transparent no-margin" data-svelte-h="svelte-we6fkv"><i>close</i></button> <div class="flex-container svelte-zyd8lx"><div style="display: flex;"><p class="bold truncate svelte-zyd8lx">${escape($miniPlayerSrcStore.video.title)}</p> <button class="m l circle transparent no-margin" data-svelte-h="svelte-8ehido"><i>close</i></button></div> <progress class="s"${add_attribute("value", currentTime, 0)}${add_attribute("max", $miniPlayerSrcStore.video.lengthSeconds, 0)}></progress></div> <video id="video" style="cursor: pointer;" ${""} autoplay${add_attribute(
    "src",
    get_store_value(playerProxyVideosStore) ? proxyVideoUrl($miniPlayerSrcStore.video.formatStreams[0].url) : $miniPlayerSrcStore.video.formatStreams[0].url,
    0
  )} class="svelte-zyd8lx"${add_attribute("currentTime", currentTime, 0)}></video></article></nav>` : ``}`;
});
const css$2 = {
  code: ".search.svelte-akif9p{width:500px}@media screen and (max-width: 1140px){.search.svelte-akif9p{width:100%}}.selected.svelte-akif9p{background-color:var(--surface-variant)}",
  map: '{"version":3,"file":"Search.svelte","sources":["Search.svelte"],"sourcesContent":["<script lang=\\"ts\\">import { goto } from \\"$app/navigation\\";\\nimport Mousetrap from \\"mousetrap\\";\\nimport { createEventDispatcher, onMount } from \\"svelte\\";\\nimport { _ } from \\"svelte-i18n\\";\\nimport { getSearchSuggestions } from \\"../api\\";\\nimport {\\n  interfaceSearchHistoryEnabled,\\n  interfaceSearchSuggestionsStore,\\n  searchHistoryStore\\n} from \\"../store\\";\\nconst dispatch = createEventDispatcher();\\nlet searchSuggestions = false;\\ninterfaceSearchSuggestionsStore.subscribe((value) => searchSuggestions = value);\\nlet search;\\nlet suggestionsForSearch = [];\\nlet selectedSuggestionIndex = -1;\\nlet showSearchBox = false;\\nlet debounceTimer;\\nfunction debouncedSearch(event) {\\n  if (!searchSuggestions) return;\\n  if (debounceTimer) clearTimeout(debounceTimer);\\n  debounceTimer = setTimeout(async () => {\\n    if (event.target.value === \\"\\") {\\n      suggestionsForSearch = [];\\n      return;\\n    }\\n    suggestionsForSearch = (await getSearchSuggestions(event.target.value)).suggestions;\\n  }, 250);\\n}\\nfunction handleSubmit() {\\n  if (search.trim() === \\"\\") return;\\n  selectedSuggestionIndex = -1;\\n  goto(`/search/${encodeURIComponent(search)}`);\\n  dispatch(\\"searchSubmitted\\");\\n  suggestionsForSearch = [];\\n  showSearchBox = false;\\n  if ($interfaceSearchHistoryEnabled && !$searchHistoryStore.includes(search)) {\\n    let pastHistory = $searchHistoryStore;\\n    if (pastHistory.length > 15) {\\n      pastHistory.pop();\\n    }\\n    searchHistoryStore.set([search, ...pastHistory]);\\n  }\\n}\\nfunction handleKeyDown(event) {\\n  if (event.key === \\"ArrowUp\\" || event.key === \\"ArrowDown\\") {\\n    event.preventDefault();\\n    const direction = event.key === \\"ArrowUp\\" ? -1 : 1;\\n    const container = document.querySelector(\\".suggestions-container\\");\\n    if (container) {\\n      const children = Array.from(container.children);\\n      const currentIndex = selectedSuggestionIndex !== -1 ? selectedSuggestionIndex : 0;\\n      const newIndex = Math.min(Math.max(currentIndex + direction, 0), children.length - 1);\\n      const selectedItem = children[newIndex];\\n      if (selectedItem) {\\n        selectedItem.scrollIntoView({ behavior: \\"smooth\\", block: \\"nearest\\" });\\n        selectedSuggestionIndex = newIndex;\\n      }\\n    }\\n  } else if (event.key === \\"Enter\\" && selectedSuggestionIndex !== -1) {\\n    search = suggestionsForSearch[selectedSuggestionIndex];\\n    handleSubmit();\\n  } else if ((event.ctrlKey || event.metaKey) && event.key === \\"k\\") {\\n    resetSearch();\\n    event.preventDefault();\\n  } else if (event.key === \\"Escape\\") {\\n    resetSearch();\\n  }\\n}\\nfunction resetSearch() {\\n  search = \\"\\";\\n  suggestionsForSearch = [];\\n  selectedSuggestionIndex = -1;\\n  showSearchBox = false;\\n}\\nonMount(() => {\\n  Mousetrap.bind([\\"ctrl+k\\", \\"command+k\\"], () => {\\n    document.getElementById(\\"search-box\\")?.focus();\\n    showSearchBox = !showSearchBox;\\n    if (!showSearchBox) resetSearch();\\n    return false;\\n  });\\n});\\n<\/script>\\n\\n<form on:submit|preventDefault={handleSubmit}>\\n\\t<div class=\\"field prefix round fill no-margin search\\">\\n\\t\\t<i class=\\"front\\">search</i>\\n\\t\\t<input\\n\\t\\t\\tid=\\"search-box\\"\\n\\t\\t\\tplaceholder={$_(\'searchPlaceholder\')}\\n\\t\\t\\tbind:value={search}\\n\\t\\t\\ton:click={async () => {\\n\\t\\t\\t\\tshowSearchBox = true;\\n\\t\\t\\t}}\\n\\t\\t/>\\n\\t\\t{#if showSearchBox}\\n\\t\\t\\t<menu class=\\"min suggestions-container\\">\\n\\t\\t\\t\\t<div class=\\"field large prefix suffix no-margin fixed\\">\\n\\t\\t\\t\\t\\t<i class=\\"front\\" on:click={() => dispatch(\'searchCancelled\')}>arrow_back</i>\\n\\t\\t\\t\\t\\t<input\\n\\t\\t\\t\\t\\t\\tplaceholder={$_(\'searchPlaceholder\')}\\n\\t\\t\\t\\t\\t\\ttype=\\"text\\"\\n\\t\\t\\t\\t\\t\\tautofocus\\n\\t\\t\\t\\t\\t\\trequired\\n\\t\\t\\t\\t\\t\\tbind:value={search}\\n\\t\\t\\t\\t\\t\\ton:keydown={handleKeyDown}\\n\\t\\t\\t\\t\\t\\ton:keyup={(event) => {\\n\\t\\t\\t\\t\\t\\t\\tif (event.key === \'Enter\') {\\n\\t\\t\\t\\t\\t\\t\\t\\thandleSubmit();\\n\\t\\t\\t\\t\\t\\t\\t} else {\\n\\t\\t\\t\\t\\t\\t\\t\\tdebouncedSearch(event);\\n\\t\\t\\t\\t\\t\\t\\t}\\n\\t\\t\\t\\t\\t\\t}}\\n\\t\\t\\t\\t\\t/>\\n\\t\\t\\t\\t\\t<i class=\\"front\\" on:click={resetSearch}>close</i>\\n\\t\\t\\t\\t</div>\\n\\t\\t\\t\\t{#if searchSuggestions}\\n\\t\\t\\t\\t\\t{#each suggestionsForSearch as suggestion, index}\\n\\t\\t\\t\\t\\t\\t<a\\n\\t\\t\\t\\t\\t\\t\\ton:click={() => {\\n\\t\\t\\t\\t\\t\\t\\t\\tsearch = suggestion;\\n\\t\\t\\t\\t\\t\\t\\t\\thandleSubmit();\\n\\t\\t\\t\\t\\t\\t\\t}}\\n\\t\\t\\t\\t\\t\\t\\tclass=\\"row\\"\\n\\t\\t\\t\\t\\t\\t\\tclass:selected={index === selectedSuggestionIndex}\\n\\t\\t\\t\\t\\t\\t\\thref={`/search/${encodeURIComponent(suggestion)}`}\\n\\t\\t\\t\\t\\t\\t>\\n\\t\\t\\t\\t\\t\\t\\t<div>{suggestion}</div>\\n\\t\\t\\t\\t\\t\\t</a>\\n\\t\\t\\t\\t\\t{/each}\\n\\t\\t\\t\\t{/if}\\n\\t\\t\\t\\t{#if !suggestionsForSearch.length && $interfaceSearchHistoryEnabled}\\n\\t\\t\\t\\t\\t{#each $searchHistoryStore as history}\\n\\t\\t\\t\\t\\t\\t<a class=\\"row\\" href={`/search/${encodeURIComponent(history)}`}>\\n\\t\\t\\t\\t\\t\\t\\t<div>{history}</div>\\n\\t\\t\\t\\t\\t\\t</a>\\n\\t\\t\\t\\t\\t{/each}\\n\\t\\t\\t\\t{/if}\\n\\t\\t\\t</menu>\\n\\t\\t{/if}\\n\\t</div>\\n</form>\\n\\n<style>\\n\\t.search {\\n\\t\\twidth: 500px;\\n\\t}\\n\\t@media screen and (max-width: 1140px) {\\n\\t\\t.search {\\n\\t\\t\\twidth: 100%;\\n\\t\\t}\\n\\t}\\n\\t.selected {\\n\\t\\tbackground-color: var(--surface-variant);\\n\\t}\\n</style>\\n"],"names":[],"mappings":"AAiJC,qBAAQ,CACP,KAAK,CAAE,KACR,CACA,OAAO,MAAM,CAAC,GAAG,CAAC,YAAY,MAAM,CAAE,CACrC,qBAAQ,CACP,KAAK,CAAE,IACR,CACD,CACA,uBAAU,CACT,gBAAgB,CAAE,IAAI,iBAAiB,CACxC"}'
};
const Search = create_ssr_component(($$result, $$props, $$bindings, slots) => {
  let $$unsubscribe_searchHistoryStore;
  let $$unsubscribe_interfaceSearchHistoryEnabled;
  let $_, $$unsubscribe__;
  $$unsubscribe_searchHistoryStore = subscribe(searchHistoryStore, (value) => value);
  $$unsubscribe_interfaceSearchHistoryEnabled = subscribe(interfaceSearchHistoryEnabled, (value) => value);
  $$unsubscribe__ = subscribe($format, (value) => $_ = value);
  createEventDispatcher();
  interfaceSearchSuggestionsStore.subscribe((value) => value);
  let search;
  $$result.css.add(css$2);
  $$unsubscribe_searchHistoryStore();
  $$unsubscribe_interfaceSearchHistoryEnabled();
  $$unsubscribe__();
  return `<form><div class="field prefix round fill no-margin search svelte-akif9p"><i class="front" data-svelte-h="svelte-t6yvho">search</i> <input id="search-box"${add_attribute("placeholder", $_("searchPlaceholder"), 0)}${add_attribute("value", search, 0)}> ${``}</div> </form>`;
});
const ApiExtended = create_ssr_component(($$result, $$props, $$bindings, slots) => {
  let $_, $$unsubscribe__;
  let $synciousStore, $$unsubscribe_synciousStore;
  $$unsubscribe__ = subscribe($format, (value) => $_ = value);
  $$unsubscribe_synciousStore = subscribe(synciousStore, (value) => $synciousStore = value);
  let synciousInstance = get_store_value(synciousInstanceStore);
  $$unsubscribe__();
  $$unsubscribe_synciousStore();
  return `<form><nav><div class="field label border max"><input name="syncious-instance" type="text"${add_attribute("value", synciousInstance, 0)}> <label for="syncious-instance">${escape($_("layout.instanceUrl"))}</label></div> <button class="square round" data-svelte-h="svelte-mof1dg"><i>done</i></button></nav></form> <nav class="no-padding"><div class="max"><p>${escape($_("enabled"))}</p></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $synciousStore, 1)}> <span></span></label></nav>`;
});
const DataPreferences = create_ssr_component(($$result, $$props, $$bindings, slots) => {
  let $_, $$unsubscribe__;
  $$unsubscribe__ = subscribe($format, (value) => $_ = value);
  $$unsubscribe__();
  return `<p style="width: 240px;"><a${add_attribute("href", `${get_store_value(instanceStore)}/preferences`, 0)} target="_blank" rel="noopener noreferrer" class="link">${escape($_("layout.dataPreferences.content"))}</a></p>`;
});
const DeArrow = create_ssr_component(($$result, $$props, $$bindings, slots) => {
  let $_, $$unsubscribe__;
  let $deArrowTitlesOnly, $$unsubscribe_deArrowTitlesOnly;
  let $deArrowEnabledStore, $$unsubscribe_deArrowEnabledStore;
  $$unsubscribe__ = subscribe($format, (value) => $_ = value);
  $$unsubscribe_deArrowTitlesOnly = subscribe(deArrowTitlesOnly, (value) => $deArrowTitlesOnly = value);
  $$unsubscribe_deArrowEnabledStore = subscribe(deArrowEnabledStore, (value) => $deArrowEnabledStore = value);
  let deArrowUrl = get_store_value(deArrowInstanceStore);
  let deArrowThumbnailUrl = get_store_value(deArrowThumbnailInstanceStore);
  $$unsubscribe__();
  $$unsubscribe_deArrowTitlesOnly();
  $$unsubscribe_deArrowEnabledStore();
  return `<form><nav><div class="field label border max"><input name="dearrow-instance" type="text"${add_attribute("value", deArrowUrl, 0)}> <label for="dearrow-instance">${escape($_("layout.instanceUrl"))}</label></div> <button class="square round" data-svelte-h="svelte-mof1dg"><i>done</i></button></nav></form> <form><nav><div class="field label border max"><input name="dearrow-thumbnail-instance" type="text"${add_attribute("value", deArrowThumbnailUrl, 0)}> <label for="dearrow-thumbnail-instance">${escape($_("layout.deArrow.thumbnailInstanceUrl"))}</label></div> <button class="square round" data-svelte-h="svelte-mof1dg"><i>done</i></button></nav></form> <nav class="no-padding"><div class="max"><p>${escape($_("layout.deArrow.titleOnly"))}</p></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $deArrowTitlesOnly, 1)}> <span></span></label></nav> <nav class="no-padding"><div class="max"><p>${escape($_("enabled"))}</p></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $deArrowEnabledStore, 1)}> <span></span></label></nav>`;
});
const Interface = create_ssr_component(($$result, $$props, $$bindings, slots) => {
  let $_, $$unsubscribe__;
  let $darkModeStore, $$unsubscribe_darkModeStore;
  let $interfaceAmoledTheme, $$unsubscribe_interfaceAmoledTheme;
  let $interfaceDisplayThumbnailAvatars, $$unsubscribe_interfaceDisplayThumbnailAvatars;
  let $interfaceSearchHistoryEnabled, $$unsubscribe_interfaceSearchHistoryEnabled;
  let $interfaceLowBandwidthMode, $$unsubscribe_interfaceLowBandwidthMode;
  let $interfaceSearchSuggestionsStore, $$unsubscribe_interfaceSearchSuggestionsStore;
  let $interfacePreviewVideoOnHoverStore, $$unsubscribe_interfacePreviewVideoOnHoverStore;
  let $interfaceAutoExpandDesc, $$unsubscribe_interfaceAutoExpandDesc;
  let $interfaceAutoExpandComments, $$unsubscribe_interfaceAutoExpandComments;
  let $interfaceRegionStore, $$unsubscribe_interfaceRegionStore;
  let $interfaceForceCase, $$unsubscribe_interfaceForceCase;
  let $interfaceDefaultPage, $$unsubscribe_interfaceDefaultPage;
  $$unsubscribe__ = subscribe($format, (value) => $_ = value);
  $$unsubscribe_darkModeStore = subscribe(darkModeStore, (value) => $darkModeStore = value);
  $$unsubscribe_interfaceAmoledTheme = subscribe(interfaceAmoledTheme, (value) => $interfaceAmoledTheme = value);
  $$unsubscribe_interfaceDisplayThumbnailAvatars = subscribe(interfaceDisplayThumbnailAvatars, (value) => $interfaceDisplayThumbnailAvatars = value);
  $$unsubscribe_interfaceSearchHistoryEnabled = subscribe(interfaceSearchHistoryEnabled, (value) => $interfaceSearchHistoryEnabled = value);
  $$unsubscribe_interfaceLowBandwidthMode = subscribe(interfaceLowBandwidthMode, (value) => $interfaceLowBandwidthMode = value);
  $$unsubscribe_interfaceSearchSuggestionsStore = subscribe(interfaceSearchSuggestionsStore, (value) => $interfaceSearchSuggestionsStore = value);
  $$unsubscribe_interfacePreviewVideoOnHoverStore = subscribe(interfacePreviewVideoOnHoverStore, (value) => $interfacePreviewVideoOnHoverStore = value);
  $$unsubscribe_interfaceAutoExpandDesc = subscribe(interfaceAutoExpandDesc, (value) => $interfaceAutoExpandDesc = value);
  $$unsubscribe_interfaceAutoExpandComments = subscribe(interfaceAutoExpandComments, (value) => $interfaceAutoExpandComments = value);
  $$unsubscribe_interfaceRegionStore = subscribe(interfaceRegionStore, (value) => $interfaceRegionStore = value);
  $$unsubscribe_interfaceForceCase = subscribe(interfaceForceCase, (value) => $interfaceForceCase = value);
  $$unsubscribe_interfaceDefaultPage = subscribe(interfaceDefaultPage, (value) => $interfaceDefaultPage = value);
  let invidiousInstance = get_store_value(instanceStore);
  get_store_value(interfaceRegionStore);
  get_store_value(interfaceForceCase);
  get_store_value(interfaceDefaultPage);
  $$unsubscribe__();
  $$unsubscribe_darkModeStore();
  $$unsubscribe_interfaceAmoledTheme();
  $$unsubscribe_interfaceDisplayThumbnailAvatars();
  $$unsubscribe_interfaceSearchHistoryEnabled();
  $$unsubscribe_interfaceLowBandwidthMode();
  $$unsubscribe_interfaceSearchSuggestionsStore();
  $$unsubscribe_interfacePreviewVideoOnHoverStore();
  $$unsubscribe_interfaceAutoExpandDesc();
  $$unsubscribe_interfaceAutoExpandComments();
  $$unsubscribe_interfaceRegionStore();
  $$unsubscribe_interfaceForceCase();
  $$unsubscribe_interfaceDefaultPage();
  return `${Capacitor.isNativePlatform() ? `<form><nav><div class="field label border max"><input name="invidious-instance" type="text"${add_attribute("value", invidiousInstance, 0)}> <label for="invidious-instance">${escape($_("layout.instanceUrl"))}</label></div> <button class="square round" data-svelte-h="svelte-juurw"><i>done</i></button></nav></form>` : ``} <div class="margin"></div> <button class="no-margin">${!$darkModeStore ? `<i data-svelte-h="svelte-922dac">dark_mode</i> <span>${escape($_("layout.theme.darkMode"))}</span>` : `<i data-svelte-h="svelte-1h1jdua">light_mode</i> <span>${escape($_("layout.theme.lightMode"))}</span>`}</button> <button><i data-svelte-h="svelte-1py0tk1">palette</i> <span>${escape($_("layout.theme.color"))}</span> <input type="color"></button> <div class="margin"></div> ${$darkModeStore ? `<div class="field no-margin"><nav class="no-padding"><div class="max"><div>${escape($_("layout.theme.AmoledTheme"))}</div></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $interfaceAmoledTheme, 1)}> <span></span></label></nav></div>` : ``} <div class="field no-margin"><nav class="no-padding"><div class="max"><div>${escape($_("layout.displayThumbnailAvatars"))}</div></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $interfaceDisplayThumbnailAvatars, 1)}> <span></span></label></nav></div> <div class="field no-margin"><nav class="no-padding"><div class="max"><div>${escape($_("layout.searchHistory"))}</div></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $interfaceSearchHistoryEnabled, 1)}> <span></span></label></nav></div> <div class="field no-margin"><nav class="no-padding"><div class="max"><div>${escape($_("layout.lowBandwidthMode"))}</div></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $interfaceLowBandwidthMode, 1)}> <span></span></label></nav></div> <div class="field no-margin"><nav class="no-padding"><div class="max"><div>${escape($_("layout.searchSuggestions"))}</div></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $interfaceSearchSuggestionsStore, 1)}> <span></span></label></nav></div> <div class="field no-margin"><nav class="no-padding"><div class="max"><div>${escape($_("layout.previewVideoOnHover"))}</div></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $interfacePreviewVideoOnHoverStore, 1)}> <span></span></label></nav></div> <div class="field no-margin"><nav class="no-padding"><div class="max"><div>${escape($_("layout.expandDescription"))}</div></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $interfaceAutoExpandDesc, 1)}> <span></span></label></nav></div> <div class="field no-margin"><nav class="no-padding"><div class="max"><div>${escape($_("layout.expandComments"))}</div></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $interfaceAutoExpandComments, 1)}> <span></span></label></nav></div> <div class="field label suffix border"><select name="region">${each(iso31661, (region) => {
    return `<option ${$interfaceRegionStore === region.alpha2 ? "selected" : ""}${add_attribute("value", region.alpha2, 0)}>${escape(region.alpha2)} - ${escape(region.name)}</option>`;
  })}</select> <label for="region">${escape($_("region"))}</label> <i data-svelte-h="svelte-1bv0s5u">arrow_drop_down</i></div> <div class="field label suffix border"><select name="case"><option ${$interfaceForceCase === null ? "selected" : ""}${add_attribute("value", null, 0)}>Default</option>${each(titleCases, (caseType) => {
    return `<option ${$interfaceForceCase === caseType ? "selected" : ""}${add_attribute("value", caseType, 0)}>${escape(letterCase(`${caseType}`, caseType))}</option>`;
  })}</select> <label for="case">${escape($_("letterCase"))}</label> <i data-svelte-h="svelte-1bv0s5u">arrow_drop_down</i></div> <div class="field label suffix border"><select name="defaultPage">${each(getPages(), (page2) => {
    return `${!page2.requiresAuth || get_store_value(authStore) ? `<option ${$interfaceDefaultPage === page2.href ? "selected" : ""}${add_attribute("value", page2.href, 0)}>${escape(page2.name)}</option>` : ``}`;
  })}</select> <label for="defaultPage">${escape($_("defaultPage"))}</label> <i data-svelte-h="svelte-1bv0s5u">arrow_drop_down</i></div> ${!Capacitor.isNativePlatform() ? `<div class="settings"><h6>${escape($_("layout.bookmarklet"))}</h6> <button class="no-margin">${escape($_("copyUrl"))}</button></div>` : ``}`;
});
const Player = create_ssr_component(($$result, $$props, $$bindings, slots) => {
  let $playerDefaultLanguage, $$unsubscribe_playerDefaultLanguage;
  let $_, $$unsubscribe__;
  let $playerMiniPlayerStore, $$unsubscribe_playerMiniPlayerStore;
  let $playerAutoPlayStore, $$unsubscribe_playerAutoPlayStore;
  let $playerAlwaysLoopStore, $$unsubscribe_playerAlwaysLoopStore;
  let $playerAndroidBgPlayer, $$unsubscribe_playerAndroidBgPlayer;
  let $playerAndroidLockOrientation, $$unsubscribe_playerAndroidLockOrientation;
  let $playerProxyVideosStore, $$unsubscribe_playerProxyVideosStore;
  let $playerSavePlaybackPositionStore, $$unsubscribe_playerSavePlaybackPositionStore;
  let $playerListenByDefaultStore, $$unsubscribe_playerListenByDefaultStore;
  let $playerTheatreModeByDefaultStore, $$unsubscribe_playerTheatreModeByDefaultStore;
  let $playerAutoplayNextByDefaultStore, $$unsubscribe_playerAutoplayNextByDefaultStore;
  let $silenceSkipperStore, $$unsubscribe_silenceSkipperStore;
  let $playerYouTubeJsAlways, $$unsubscribe_playerYouTubeJsAlways;
  let $playerYouTubeJsFallback, $$unsubscribe_playerYouTubeJsFallback;
  $$unsubscribe_playerDefaultLanguage = subscribe(playerDefaultLanguage, (value) => $playerDefaultLanguage = value);
  $$unsubscribe__ = subscribe($format, (value) => $_ = value);
  $$unsubscribe_playerMiniPlayerStore = subscribe(playerMiniPlayerStore, (value) => $playerMiniPlayerStore = value);
  $$unsubscribe_playerAutoPlayStore = subscribe(playerAutoPlayStore, (value) => $playerAutoPlayStore = value);
  $$unsubscribe_playerAlwaysLoopStore = subscribe(playerAlwaysLoopStore, (value) => $playerAlwaysLoopStore = value);
  $$unsubscribe_playerAndroidBgPlayer = subscribe(playerAndroidBgPlayer, (value) => $playerAndroidBgPlayer = value);
  $$unsubscribe_playerAndroidLockOrientation = subscribe(playerAndroidLockOrientation, (value) => $playerAndroidLockOrientation = value);
  $$unsubscribe_playerProxyVideosStore = subscribe(playerProxyVideosStore, (value) => $playerProxyVideosStore = value);
  $$unsubscribe_playerSavePlaybackPositionStore = subscribe(playerSavePlaybackPositionStore, (value) => $playerSavePlaybackPositionStore = value);
  $$unsubscribe_playerListenByDefaultStore = subscribe(playerListenByDefaultStore, (value) => $playerListenByDefaultStore = value);
  $$unsubscribe_playerTheatreModeByDefaultStore = subscribe(playerTheatreModeByDefaultStore, (value) => $playerTheatreModeByDefaultStore = value);
  $$unsubscribe_playerAutoplayNextByDefaultStore = subscribe(playerAutoplayNextByDefaultStore, (value) => $playerAutoplayNextByDefaultStore = value);
  $$unsubscribe_silenceSkipperStore = subscribe(silenceSkipperStore, (value) => $silenceSkipperStore = value);
  $$unsubscribe_playerYouTubeJsAlways = subscribe(playerYouTubeJsAlways, (value) => $playerYouTubeJsAlways = value);
  $$unsubscribe_playerYouTubeJsFallback = subscribe(playerYouTubeJsFallback, (value) => $playerYouTubeJsFallback = value);
  get_store_value(playerDefaultLanguage);
  const languageNames = ISO6391.getAllCodes().map((code) => ISO6391.getName(code).toLocaleLowerCase());
  $$unsubscribe_playerDefaultLanguage();
  $$unsubscribe__();
  $$unsubscribe_playerMiniPlayerStore();
  $$unsubscribe_playerAutoPlayStore();
  $$unsubscribe_playerAlwaysLoopStore();
  $$unsubscribe_playerAndroidBgPlayer();
  $$unsubscribe_playerAndroidLockOrientation();
  $$unsubscribe_playerProxyVideosStore();
  $$unsubscribe_playerSavePlaybackPositionStore();
  $$unsubscribe_playerListenByDefaultStore();
  $$unsubscribe_playerTheatreModeByDefaultStore();
  $$unsubscribe_playerAutoplayNextByDefaultStore();
  $$unsubscribe_silenceSkipperStore();
  $$unsubscribe_playerYouTubeJsAlways();
  $$unsubscribe_playerYouTubeJsFallback();
  return `<div class="margin"></div> <div class="field label suffix border"><select name="case">${each(languageNames, (language) => {
    return `<option ${$playerDefaultLanguage === language ? "selected" : ""}${add_attribute("value", language, 0)}>${escape(titleCase(language))}</option>`;
  })}</select> <label for="case">${escape($_("player.defaultLanguage"))}</label> <i data-svelte-h="svelte-1bv0s5u">arrow_drop_down</i></div> <div class="field no-margin"><nav class="no-padding"><div class="max"><div>${escape($_("layout.player.miniPlayer"))}</div></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $playerMiniPlayerStore, 1)}> <span></span></label></nav></div> <div class="field no-margin"><nav class="no-padding"><div class="max"><div>${escape($_("layout.player.autoPlay"))}</div></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $playerAutoPlayStore, 1)}> <span></span></label></nav></div> <div class="field no-margin"><nav class="no-padding"><div class="max"><div>${escape($_("layout.player.alwaysLoopVideo"))}</div></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $playerAlwaysLoopStore, 1)}> <span></span></label></nav></div> ${Capacitor.getPlatform() === "android" ? `<div class="field no-margin"><nav class="no-padding"><div class="max"><div>${escape($_("layout.player.backgroundPlay"))}</div></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $playerAndroidBgPlayer, 1)}> <span></span></label></nav></div> <div class="field no-margin"><nav class="no-padding"><div class="max"><div>${escape($_("layout.player.lockOrientation"))}</div></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $playerAndroidLockOrientation, 1)}> <span></span></label></nav></div>` : ``} ${Capacitor.isNativePlatform() ? `<div class="field no-margin"><nav class="no-padding"><div class="max"><div>${escape($_("layout.player.proxyVideos"))}</div></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $playerProxyVideosStore, 1)}> <span></span></label></nav></div>` : ``} <div class="field no-margin"><nav class="no-padding"><div class="max"><div>${escape($_("layout.player.savePlaybackPosition"))}</div></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $playerSavePlaybackPositionStore, 1)}> <span></span></label></nav></div> <div class="field no-margin"><nav class="no-padding"><div class="max"><div>${escape($_("layout.player.listenByDefault"))}</div></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $playerListenByDefaultStore, 1)}> <span></span></label></nav></div> <div class="field no-margin m l"><nav class="no-padding"><div class="max"><div>${escape($_("layout.player.theatreModeByDefault"))}</div></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $playerTheatreModeByDefaultStore, 1)}> <span></span></label></nav></div> <div class="field no-margin"><nav class="no-padding"><div class="max"><div>${escape($_("layout.player.autoPlayNextByDefault"))}</div></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $playerAutoplayNextByDefaultStore, 1)}> <span></span></label></nav></div> <div class="field no-margin"><nav class="no-padding"><div class="max"><div>${escape($_("layout.player.silenceSkipper"))}</div></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $silenceSkipperStore, 1)}> <span></span></label></nav></div> ${Capacitor.isNativePlatform() ? `<div class="field no-margin"><nav class="no-padding"><div class="max"><div>${escape($_("layout.player.youtubeJsAlways"))}</div></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $playerYouTubeJsAlways, 1)}> <span></span></label></nav></div> <div class="field no-margin"><nav class="no-padding"><div class="max"><div>${escape($_("layout.player.youtubeJsFallback"))}</div></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $playerYouTubeJsFallback, 1)}> <span></span></label></nav></div>` : ``}`;
});
const RYD = create_ssr_component(($$result, $$props, $$bindings, slots) => {
  let $_, $$unsubscribe__;
  let $returnYtDislikesStore, $$unsubscribe_returnYtDislikesStore;
  $$unsubscribe__ = subscribe($format, (value) => $_ = value);
  $$unsubscribe_returnYtDislikesStore = subscribe(returnYtDislikesStore, (value) => $returnYtDislikesStore = value);
  let returnYTInstance = get_store_value(returnYTDislikesInstanceStore);
  $$unsubscribe__();
  $$unsubscribe_returnYtDislikesStore();
  return `<form><nav><div class="field label border max"><input name="returnyt-instance" type="text"${add_attribute("value", returnYTInstance, 0)}> <label for="returnyt-instance">${escape($_("layout.instanceUrl"))}</label></div> <button class="square round" data-svelte-h="svelte-mof1dg"><i>done</i></button></nav></form> <nav class="no-padding"><div class="max"><p>${escape($_("enabled"))}</p></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $returnYtDislikesStore, 1)}> <span></span></label></nav>`;
});
const SponsorBlock = create_ssr_component(($$result, $$props, $$bindings, slots) => {
  let $_, $$unsubscribe__;
  let $sponsorBlockStore, $$unsubscribe_sponsorBlockStore;
  let $sponsorBlockDisplayToastStore, $$unsubscribe_sponsorBlockDisplayToastStore;
  let $sponsorBlockTimelineStore, $$unsubscribe_sponsorBlockTimelineStore;
  $$unsubscribe__ = subscribe($format, (value) => $_ = value);
  $$unsubscribe_sponsorBlockStore = subscribe(sponsorBlockStore, (value) => $sponsorBlockStore = value);
  $$unsubscribe_sponsorBlockDisplayToastStore = subscribe(sponsorBlockDisplayToastStore, (value) => $sponsorBlockDisplayToastStore = value);
  $$unsubscribe_sponsorBlockTimelineStore = subscribe(sponsorBlockTimelineStore, (value) => $sponsorBlockTimelineStore = value);
  let sponsorCategoriesList = [];
  sponsorBlockCategoriesStore.subscribe((value) => sponsorCategoriesList = value);
  let sponsorBlockInstance = get_store_value(sponsorBlockUrlStore);
  const sponsorCategories = [
    {
      name: $_("layout.sponsors.sponsor"),
      category: "sponsor"
    },
    {
      name: $_("layout.sponsors.unpaidSelfPromotion"),
      category: "selfpromo"
    },
    {
      name: $_("layout.sponsors.interactionReminder"),
      category: "interaction"
    },
    {
      name: $_("layout.sponsors.intermissionIntroAnimation"),
      category: "intro"
    },
    {
      name: $_("layout.sponsors.credits"),
      category: "outro"
    },
    {
      name: $_("layout.sponsors.preViewRecapHook"),
      category: "preview"
    },
    {
      name: $_("layout.sponsors.tangentJokes"),
      category: "filler"
    }
  ];
  $$unsubscribe__();
  $$unsubscribe_sponsorBlockStore();
  $$unsubscribe_sponsorBlockDisplayToastStore();
  $$unsubscribe_sponsorBlockTimelineStore();
  return `<form><nav><div class="field label border max"><input name="sponsorblock-instance" type="text"${add_attribute("value", sponsorBlockInstance, 0)}> <label for="sponsorblock-instance">${escape($_("layout.instanceUrl"))}</label></div> <button class="square round" data-svelte-h="svelte-mof1dg"><i>done</i></button></nav></form> <nav class="no-padding"><div class="max"><p>${escape($_("enabled"))}</p></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $sponsorBlockStore, 1)}> <span></span></label></nav> <nav class="no-padding"><div class="max"><p>${escape($_("layout.sponsors.disableToast"))}</p></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $sponsorBlockDisplayToastStore, 1)}> <span></span></label></nav> <nav class="no-padding"><div class="max"><p>${escape($_("layout.sponsors.disableTimeline"))}</p></div> <label class="switch"><input type="checkbox"${add_attribute("checked", $sponsorBlockTimelineStore, 1)}> <span></span></label></nav> <hr style="margin: 1em 0;"> <p class="bold">${escape($_("layout.sponsors.Catagories"))}</p> ${each(sponsorCategories, (sponsor) => {
    return `<div class="field middle-align no-margin"><nav class="no-padding"><div class="max"><p>${escape(sponsor.name)}</p></div> <label class="switch"><input type="checkbox" ${sponsorCategoriesList.includes(sponsor.category) ? "checked" : ""}> <span></span> </label></nav> </div>`;
  })}`;
});
const css$1 = {
  code: "dialog.svelte-z8rzdk.svelte-z8rzdk{width:1320px}.tabbed.svelte-z8rzdk>a.svelte-z8rzdk{flex:none}@media screen and (max-width: 1320px){.tabbed.svelte-z8rzdk.svelte-z8rzdk{display:flex !important;flex-direction:column !important;gap:0 !important;flex:0 !important;margin-bottom:1em !important;align-items:start !important;padding:1em 0 !important;background-color:transparent;border-bottom:solid 1px var(--outline-variant)}.tabbed.svelte-z8rzdk>a.svelte-z8rzdk{font-size:1.5rem !important;padding:0.5em 0.3em !important;border-radius:3em !important}.tabbed.small.svelte-z8rzdk.svelte-z8rzdk{block-size:100% !important;border-radius:0 !important}}",
  map: `{"version":3,"file":"Settings.svelte","sources":["Settings.svelte"],"sourcesContent":["<script lang=\\"ts\\">import ISO6391 from \\"iso-639-1\\";\\nimport { onMount } from \\"svelte\\";\\nimport { _ } from \\"svelte-i18n\\";\\nimport { get } from \\"svelte/store\\";\\nimport {\\n  deArrowInstanceStore,\\n  deArrowThumbnailInstanceStore,\\n  instanceStore,\\n  interfaceDefaultPage,\\n  interfaceForceCase,\\n  interfaceRegionStore,\\n  playerDefaultLanguage,\\n  returnYTDislikesInstanceStore,\\n  sponsorBlockCategoriesStore,\\n  sponsorBlockUrlStore,\\n  synciousInstanceStore\\n} from \\"../../store\\";\\nimport ApiExtended from \\"./ApiExtended.svelte\\";\\nimport DataPreferences from \\"./DataPreferences.svelte\\";\\nimport DeArrow from \\"./DeArrow.svelte\\";\\nimport Interface from \\"./Interface.svelte\\";\\nimport Player from \\"./Player.svelte\\";\\nimport Ryd from \\"./RYD.svelte\\";\\nimport SponsorBlock from \\"./SponsorBlock.svelte\\";\\nlet sponsorCategoriesList = [];\\nsponsorBlockCategoriesStore.subscribe((value) => sponsorCategoriesList = value);\\nlet sponsorBlockInstance = get(sponsorBlockUrlStore);\\nlet synciousInstance = get(synciousInstanceStore);\\nlet returnYTInstance = get(returnYTDislikesInstanceStore);\\nlet invidiousInstance = get(instanceStore);\\nlet deArrowUrl = get(deArrowInstanceStore);\\nlet deArrowThumbnailUrl = get(deArrowThumbnailInstanceStore);\\nlet region = get(interfaceRegionStore);\\nlet forceCase = get(interfaceForceCase);\\nlet defaultLanguage = get(playerDefaultLanguage);\\nlet defaultPage = get(interfaceDefaultPage);\\nconst languageNames = ISO6391.getAllCodes().map(\\n  (code) => ISO6391.getName(code).toLocaleLowerCase()\\n);\\nconst sponsorCategories = [\\n  { name: $_(\\"layout.sponsors.sponsor\\"), category: \\"sponsor\\" },\\n  { name: $_(\\"layout.sponsors.unpaidSelfPromotion\\"), category: \\"selfpromo\\" },\\n  { name: $_(\\"layout.sponsors.interactionReminder\\"), category: \\"interaction\\" },\\n  { name: $_(\\"layout.sponsors.intermissionIntroAnimation\\"), category: \\"intro\\" },\\n  { name: $_(\\"layout.sponsors.credits\\"), category: \\"outro\\" },\\n  { name: $_(\\"layout.sponsors.preViewRecapHook\\"), category: \\"preview\\" },\\n  { name: $_(\\"layout.sponsors.tangentJokes\\"), category: \\"filler\\" }\\n];\\nfunction toggleSponsor(category) {\\n  if (sponsorCategoriesList.includes(category)) {\\n    sponsorBlockCategoriesStore.set(sponsorCategoriesList.filter((value) => value !== category));\\n  } else {\\n    sponsorCategoriesList.push(category);\\n    sponsorBlockCategoriesStore.set(sponsorCategoriesList);\\n  }\\n}\\nlet activeTab = \\"interface\\";\\nlet dialogType = \\"\\";\\nfunction checkWidth() {\\n  if (innerWidth <= 1320) {\\n    dialogType = \\"right\\";\\n  } else {\\n    dialogType = \\"\\";\\n  }\\n}\\nonMount(() => {\\n  checkWidth();\\n  addEventListener(\\"resize\\", () => checkWidth());\\n  if (!get(playerDefaultLanguage)) {\\n    const languageCode = navigator.language || navigator.languages[0];\\n    const languageName = ISO6391.getName(languageCode.split(\\"-\\")[0]);\\n    if (languageName) {\\n      playerDefaultLanguage.set(languageName.toLowerCase());\\n    }\\n  }\\n});\\n<\/script>\\n\\n<dialog id=\\"dialog-settings\\" class={dialogType}>\\n\\t<nav style=\\"margin-bottom: 1em;\\">\\n\\t\\t<h4 class=\\"max\\">{$_('layout.settings')}</h4>\\n\\t\\t<button class=\\"circle transparent\\" data-ui=\\"#dialog-settings\\"><i>close</i></button>\\n\\t</nav>\\n\\n\\t<div>\\n\\t\\t<nav class=\\"tabbed small\\">\\n\\t\\t\\t<a class:active={activeTab === 'interface'} on:click={() => (activeTab = 'interface')}>\\n\\t\\t\\t\\t<i>grid_view</i>\\n\\t\\t\\t\\t<span>{$_('layout.interface')}</span>\\n\\t\\t\\t</a>\\n\\t\\t\\t<a class:active={activeTab === 'player'} on:click={() => (activeTab = 'player')}>\\n\\t\\t\\t\\t<i>smart_display</i>\\n\\t\\t\\t\\t<span>{$_('layout.player.title')}</span>\\n\\t\\t\\t</a>\\n\\t\\t\\t<a class:active={activeTab === 'data'} on:click={() => (activeTab = 'data')}>\\n\\t\\t\\t\\t<i>save</i>\\n\\t\\t\\t\\t<span>{$_('layout.dataPreferences.dataPreferences')}</span>\\n\\t\\t\\t</a>\\n\\t\\t\\t<a class:active={activeTab === 'ryd'} on:click={() => (activeTab = 'ryd')}>\\n\\t\\t\\t\\t<i>thumb_down</i>\\n\\t\\t\\t\\t<span>RYD</span>\\n\\t\\t\\t</a>\\n\\t\\t\\t<a class:active={activeTab === 'api extended'} on:click={() => (activeTab = 'api extended')}>\\n\\t\\t\\t\\t<i>sync</i>\\n\\t\\t\\t\\t<span>API Extended</span>\\n\\t\\t\\t</a>\\n\\t\\t\\t<a class:active={activeTab === 'sponsorblock'} on:click={() => (activeTab = 'sponsorblock')}>\\n\\t\\t\\t\\t<i>block</i>\\n\\t\\t\\t\\t<span>Sponsorblock</span>\\n\\t\\t\\t</a>\\n\\t\\t\\t<a class:active={activeTab === 'dearrow'} on:click={() => (activeTab = 'dearrow')}>\\n\\t\\t\\t\\t<i>keyboard_double_arrow_down</i>\\n\\t\\t\\t\\t<span>{$_('layout.deArrow.title')}</span>\\n\\t\\t\\t</a>\\n\\t\\t\\t<a href=\\"https://github.com/sponsors/WardPearce\\" target=\\"_blank\\" referrerpolicy=\\"no-referrer\\">\\n\\t\\t\\t\\t<i>favorite</i>\\n\\t\\t\\t\\t<span>{$_('donate')}</span>\\n\\t\\t\\t</a>\\n\\t\\t\\t<a\\n\\t\\t\\t\\thref=\\"https://github.com/Materialious/Materialious\\"\\n\\t\\t\\t\\ttarget=\\"_blank\\"\\n\\t\\t\\t\\treferrerpolicy=\\"no-referrer\\"\\n\\t\\t\\t>\\n\\t\\t\\t\\t<i>code</i>\\n\\t\\t\\t\\t<span>GitHub</span>\\n\\t\\t\\t</a>\\n\\t\\t</nav>\\n\\t\\t<div class=\\"page padding\\" class:active={activeTab === 'interface'}>\\n\\t\\t\\t<Interface />\\n\\t\\t</div>\\n\\t\\t<div class=\\"page padding\\" class:active={activeTab === 'player'}>\\n\\t\\t\\t<Player />\\n\\t\\t</div>\\n\\t\\t<div class=\\"page padding\\" class:active={activeTab === 'data'}>\\n\\t\\t\\t<DataPreferences />\\n\\t\\t</div>\\n\\t\\t<div class=\\"page padding\\" class:active={activeTab === 'ryd'}>\\n\\t\\t\\t<Ryd />\\n\\t\\t</div>\\n\\t\\t<div class=\\"page padding\\" class:active={activeTab === 'api extended'}>\\n\\t\\t\\t<ApiExtended />\\n\\t\\t</div>\\n\\t\\t<div class=\\"page padding\\" class:active={activeTab === 'sponsorblock'}>\\n\\t\\t\\t<SponsorBlock />\\n\\t\\t</div>\\n\\t\\t<div class=\\"page padding\\" class:active={activeTab === 'dearrow'}>\\n\\t\\t\\t<DeArrow />\\n\\t\\t</div>\\n\\t</div>\\n</dialog>\\n\\n<style>\\n\\tdialog {\\n\\t\\twidth: 1320px;\\n\\t}\\n\\n\\t.tabbed > a {\\n\\t\\tflex: none;\\n\\t}\\n\\n\\t@media screen and (max-width: 1320px) {\\n\\t\\t.tabbed {\\n\\t\\t\\tdisplay: flex !important;\\n\\t\\t\\tflex-direction: column !important;\\n\\t\\t\\tgap: 0 !important;\\n\\t\\t\\tflex: 0 !important;\\n\\t\\t\\tmargin-bottom: 1em !important;\\n\\t\\t\\talign-items: start !important;\\n\\t\\t\\tpadding: 1em 0 !important;\\n\\t\\t\\tbackground-color: transparent;\\n\\t\\t\\tborder-bottom: solid 1px var(--outline-variant);\\n\\t\\t}\\n\\n\\t\\t.tabbed > a {\\n\\t\\t\\tfont-size: 1.5rem !important;\\n\\t\\t\\tpadding: 0.5em 0.3em !important;\\n\\t\\t\\tborder-radius: 3em !important;\\n\\t\\t}\\n\\n\\t\\t.tabbed.small {\\n\\t\\t\\tblock-size: 100% !important;\\n\\t\\t\\tborder-radius: 0 !important;\\n\\t\\t}\\n\\t}\\n</style>\\n"],"names":[],"mappings":"AAwJC,kCAAO,CACN,KAAK,CAAE,MACR,CAEA,qBAAO,CAAG,eAAE,CACX,IAAI,CAAE,IACP,CAEA,OAAO,MAAM,CAAC,GAAG,CAAC,YAAY,MAAM,CAAE,CACrC,mCAAQ,CACP,OAAO,CAAE,IAAI,CAAC,UAAU,CACxB,cAAc,CAAE,MAAM,CAAC,UAAU,CACjC,GAAG,CAAE,CAAC,CAAC,UAAU,CACjB,IAAI,CAAE,CAAC,CAAC,UAAU,CAClB,aAAa,CAAE,GAAG,CAAC,UAAU,CAC7B,WAAW,CAAE,KAAK,CAAC,UAAU,CAC7B,OAAO,CAAE,GAAG,CAAC,CAAC,CAAC,UAAU,CACzB,gBAAgB,CAAE,WAAW,CAC7B,aAAa,CAAE,KAAK,CAAC,GAAG,CAAC,IAAI,iBAAiB,CAC/C,CAEA,qBAAO,CAAG,eAAE,CACX,SAAS,CAAE,MAAM,CAAC,UAAU,CAC5B,OAAO,CAAE,KAAK,CAAC,KAAK,CAAC,UAAU,CAC/B,aAAa,CAAE,GAAG,CAAC,UACpB,CAEA,OAAO,kCAAO,CACb,UAAU,CAAE,IAAI,CAAC,UAAU,CAC3B,aAAa,CAAE,CAAC,CAAC,UAClB,CACD"}`
};
const Settings = create_ssr_component(($$result, $$props, $$bindings, slots) => {
  let $_, $$unsubscribe__;
  $$unsubscribe__ = subscribe($format, (value) => $_ = value);
  sponsorBlockCategoriesStore.subscribe((value) => value);
  get_store_value(sponsorBlockUrlStore);
  get_store_value(synciousInstanceStore);
  get_store_value(returnYTDislikesInstanceStore);
  get_store_value(instanceStore);
  get_store_value(deArrowInstanceStore);
  get_store_value(deArrowThumbnailInstanceStore);
  get_store_value(interfaceRegionStore);
  get_store_value(interfaceForceCase);
  get_store_value(playerDefaultLanguage);
  get_store_value(interfaceDefaultPage);
  ISO6391.getAllCodes().map((code) => ISO6391.getName(code).toLocaleLowerCase());
  [
    {
      name: $_("layout.sponsors.sponsor"),
      category: "sponsor"
    },
    {
      name: $_("layout.sponsors.unpaidSelfPromotion"),
      category: "selfpromo"
    },
    {
      name: $_("layout.sponsors.interactionReminder"),
      category: "interaction"
    },
    {
      name: $_("layout.sponsors.intermissionIntroAnimation"),
      category: "intro"
    },
    {
      name: $_("layout.sponsors.credits"),
      category: "outro"
    },
    {
      name: $_("layout.sponsors.preViewRecapHook"),
      category: "preview"
    },
    {
      name: $_("layout.sponsors.tangentJokes"),
      category: "filler"
    }
  ];
  let dialogType = "";
  $$result.css.add(css$1);
  $$unsubscribe__();
  return `<dialog id="dialog-settings" class="${escape(null_to_empty(dialogType), true) + " svelte-z8rzdk"}"><nav style="margin-bottom: 1em;"><h4 class="max">${escape($_("layout.settings"))}</h4> <button class="circle transparent" data-ui="#dialog-settings" data-svelte-h="svelte-p603ut"><i>close</i></button></nav> <div><nav class="tabbed small svelte-z8rzdk"><a class="${["svelte-z8rzdk", "active"].join(" ").trim()}"><i data-svelte-h="svelte-18r7p4y">grid_view</i> <span>${escape($_("layout.interface"))}</span></a> <a class="${["svelte-z8rzdk", ""].join(" ").trim()}"><i data-svelte-h="svelte-19p0qoa">smart_display</i> <span>${escape($_("layout.player.title"))}</span></a> <a class="${["svelte-z8rzdk", ""].join(" ").trim()}"><i data-svelte-h="svelte-1me5pen">save</i> <span>${escape($_("layout.dataPreferences.dataPreferences"))}</span></a> <a class="${["svelte-z8rzdk", ""].join(" ").trim()}" data-svelte-h="svelte-1m1jw53"><i>thumb_down</i> <span>RYD</span></a> <a class="${["svelte-z8rzdk", ""].join(" ").trim()}" data-svelte-h="svelte-bp7ql1"><i>sync</i> <span>API Extended</span></a> <a class="${["svelte-z8rzdk", ""].join(" ").trim()}" data-svelte-h="svelte-2wpssj"><i>block</i> <span>Sponsorblock</span></a> <a class="${["svelte-z8rzdk", ""].join(" ").trim()}"><i data-svelte-h="svelte-1y1csxq">keyboard_double_arrow_down</i> <span>${escape($_("layout.deArrow.title"))}</span></a> <a href="https://github.com/sponsors/WardPearce" target="_blank" referrerpolicy="no-referrer" class="svelte-z8rzdk"><i data-svelte-h="svelte-159712o">favorite</i> <span>${escape($_("donate"))}</span></a> <a href="https://github.com/Materialious/Materialious" target="_blank" referrerpolicy="no-referrer" class="svelte-z8rzdk" data-svelte-h="svelte-ipe90v"><i>code</i> <span>GitHub</span></a></nav> <div class="${["page padding", "active"].join(" ").trim()}">${validate_component(Interface, "Interface").$$render($$result, {}, {}, {})}</div> <div class="${["page padding", ""].join(" ").trim()}">${validate_component(Player, "Player").$$render($$result, {}, {}, {})}</div> <div class="${["page padding", ""].join(" ").trim()}">${validate_component(DataPreferences, "DataPreferences").$$render($$result, {}, {}, {})}</div> <div class="${["page padding", ""].join(" ").trim()}">${validate_component(RYD, "Ryd").$$render($$result, {}, {}, {})}</div> <div class="${["page padding", ""].join(" ").trim()}">${validate_component(ApiExtended, "ApiExtended").$$render($$result, {}, {}, {})}</div> <div class="${["page padding", ""].join(" ").trim()}">${validate_component(SponsorBlock, "SponsorBlock").$$render($$result, {}, {}, {})}</div> <div class="${["page padding", ""].join(" ").trim()}">${validate_component(DeArrow, "DeArrow").$$render($$result, {}, {}, {})}</div></div> </dialog>`;
});
const SyncParty = create_ssr_component(($$result, $$props, $$bindings, slots) => {
  let $syncPartyPeerStore, $$unsubscribe_syncPartyPeerStore;
  let $syncPartyConnectionsStore, $$unsubscribe_syncPartyConnectionsStore;
  let $$unsubscribe_page;
  let $_, $$unsubscribe__;
  $$unsubscribe_syncPartyPeerStore = subscribe(syncPartyPeerStore, (value) => $syncPartyPeerStore = value);
  $$unsubscribe_syncPartyConnectionsStore = subscribe(syncPartyConnectionsStore, (value) => $syncPartyConnectionsStore = value);
  $$unsubscribe_page = subscribe(page, (value) => value);
  $$unsubscribe__ = subscribe($format, (value) => $_ = value);
  page.subscribe((newPage) => {
    if (!newPage.url.pathname.startsWith("/watch") && $syncPartyPeerStore) {
      $syncPartyConnectionsStore?.forEach((conn) => {
        conn.send({
          events: [{ type: "goto", path: newPage.url.pathname }]
        });
      });
    }
  });
  onDestroy(() => {
    if ($syncPartyPeerStore) {
      $syncPartyPeerStore.destroy();
      set_store_value(syncPartyPeerStore, $syncPartyPeerStore = null, $syncPartyPeerStore);
    }
  });
  $$unsubscribe_syncPartyPeerStore();
  $$unsubscribe_syncPartyConnectionsStore();
  $$unsubscribe_page();
  $$unsubscribe__();
  return `<dialog id="sync-party"><h6>${escape($_("layout.syncParty"))}</h6> <p>${escape($_("layout.syncPartyWarning"))}</p> ${$syncPartyPeerStore ? `<nav><div class="field label border max"><input name="sync-share" readonly${add_attribute("value", `${location.origin}?sync=${$syncPartyPeerStore.id}`, 0)} type="text"> <label class="active" for="sync-share" data-svelte-h="svelte-ye6v5k">Share URL</label></div> <button class="square round" data-svelte-h="svelte-7i4uez"><i>content_copy</i></button></nav>` : ``} <div class="space"></div> <button class="no-margin"${add_attribute("data-ui", `${$syncPartyPeerStore ? "#sync-party" : ""}`, 0)}>${$syncPartyPeerStore ? ` ${escape($_("layout.endSyncParty"))}` : ` ${escape($_("layout.startSyncParty"))}`}</button></dialog> <div class="snackbar" id="sync-party-connection-join"><i data-svelte-h="svelte-r45r1b">person_add</i> <span>${escape($_("syncParty.userJoined"))}</span></div> <div class="snackbar" id="sync-party-connection-left"><i data-svelte-h="svelte-1rehwxo">person_remove</i> <span>${escape($_("syncParty.userLeft"))}</span></div> <div class="snackbar" id="sync-party-private-page"><i data-svelte-h="svelte-d119ld">shield_person</i> <span>${escape($_("syncParty.userOnPrivatePage"))}</span></div>`;
});
const pwaInfo = { "pwaInDevEnvironment": false, "webManifest": { "href": "/manifest.webmanifest", "useCredentials": false, "linkTag": '<link rel="manifest" href="/manifest.webmanifest">' }, "registerSW": { "inline": true, "mode": "inline", "inlinePath": "/sw.js", "registerPath": "/registerSW.js", "type": "classic", "scope": "/", "scriptTag": `<script id="vite-plugin-pwa:inline-sw">if('serviceWorker' in navigator) {window.addEventListener('load', () => {navigator.serviceWorker.register('/sw.js', { scope: '/' })})}<\/script>` } };
const css = {
  code: "nav.left.svelte-16bpv4m a.svelte-16bpv4m{font-size:0.8em}",
  map: `{"version":3,"file":"+layout.svelte","sources":["+layout.svelte"],"sourcesContent":["<script lang=\\"ts\\">import { afterNavigate, beforeNavigate, goto } from \\"$app/navigation\\";\\nimport { navigating } from \\"$app/stores\\";\\nimport \\"$lib/android/http/androidRequests\\";\\nimport colorTheme, { convertToHexColorCode } from \\"$lib/android/plugins/colorTheme\\";\\nimport { getFeed } from \\"$lib/api/index\\";\\nimport Logo from \\"$lib/components/Logo.svelte\\";\\nimport MiniPlayer from \\"$lib/components/MiniPlayer.svelte\\";\\nimport PageLoading from \\"$lib/components/PageLoading.svelte\\";\\nimport Search from \\"$lib/components/Search.svelte\\";\\nimport Settings from \\"$lib/components/Settings/Settings.svelte\\";\\nimport SyncParty from \\"$lib/components/SyncParty.svelte\\";\\nimport Thumbnail from \\"$lib/components/Thumbnail.svelte\\";\\nimport { bookmarkletLoadFromUrl, loadSettingsFromEnv } from \\"$lib/externalSettings\\";\\nimport { getPages } from \\"$lib/navPages\\";\\nimport {\\n  activePageStore,\\n  authStore,\\n  darkModeStore,\\n  instanceStore,\\n  interfaceAmoledTheme,\\n  showWarningStore,\\n  syncPartyPeerStore,\\n  themeColorStore\\n} from \\"$lib/store\\";\\nimport { setAmoledTheme, setStatusBarColor, setTheme } from \\"$lib/theme\\";\\nimport { App } from \\"@capacitor/app\\";\\nimport { Browser } from \\"@capacitor/browser\\";\\nimport { Capacitor } from \\"@capacitor/core\\";\\nimport \\"beercss\\";\\nimport ui from \\"beercss\\";\\nimport \\"material-dynamic-colors\\";\\nimport { onMount, tick } from \\"svelte\\";\\nimport { _ } from \\"svelte-i18n\\";\\nimport { get } from \\"svelte/store\\";\\nimport { pwaInfo } from \\"virtual:pwa-info\\";\\nlet mobileSearchShow = false;\\nlet currentPage = \\"\\";\\nactivePageStore.subscribe((page) => currentPage = page);\\nlet isLoggedIn = false;\\nauthStore.subscribe((value) => {\\n  isLoggedIn = value !== null;\\n});\\nlet notifications = [];\\ninterfaceAmoledTheme.subscribe(async () => {\\n  setAmoledTheme();\\n  await setStatusBarColor();\\n});\\ndarkModeStore.subscribe(async () => {\\n  setTheme();\\n  setAmoledTheme();\\n  await setStatusBarColor();\\n});\\nApp.addListener(\\"appUrlOpen\\", (data) => {\\n  const url = new URL(data.url);\\n  if (url.protocol !== \\"materialious-auth:\\") {\\n    let videoId = url.searchParams.get(\\"v\\");\\n    if (!videoId) {\\n      videoId = url.pathname.split(\\"/\\")[1];\\n    }\\n    if (!videoId) {\\n      return;\\n    }\\n    goto(\`/watch/\${videoId}\`);\\n  } else {\\n    const username = url.searchParams.get(\\"username\\");\\n    const token = url.searchParams.get(\\"token\\");\\n    if (username && token) {\\n      authStore.set({\\n        username,\\n        token\\n      });\\n    }\\n  }\\n});\\nasync function login() {\\n  const path = new URL(\`\${get(instanceStore)}/authorize_token\`);\\n  const searchParams = new URLSearchParams({\\n    scopes: \\":feed,:subscriptions*,:playlists*,:history*,:notifications*\\"\\n  });\\n  if (Capacitor.getPlatform() === \\"android\\") {\\n    searchParams.set(\\"callback_url\\", \\"materialious-auth://\\");\\n    path.search = searchParams.toString();\\n    await Browser.open({ url: path.toString() });\\n  } else {\\n    searchParams.set(\\"callback_url\\", \`\${location.origin}/auth\`);\\n    path.search = searchParams.toString();\\n    document.location.href = path.toString();\\n  }\\n}\\nfunction logout() {\\n  authStore.set(null);\\n  goto(\\"/\\");\\n}\\nasync function loadNotifications() {\\n  const feed = await getFeed(15, 1);\\n  notifications = feed.notifications;\\n}\\nlet scrollPositions = /* @__PURE__ */ new Map();\\nlet scrollableRoot = null;\\nbeforeNavigate(({ from }) => {\\n  if (from?.url && scrollableRoot) {\\n    scrollPositions.set(from.url.pathname, scrollableRoot.scrollTop);\\n  }\\n});\\nafterNavigate(async ({ to, type }) => {\\n  if (!scrollableRoot) return;\\n  if (to?.url && scrollPositions.has(to.url.pathname)) {\\n    if (type === \\"popstate\\") {\\n      await tick();\\n      scrollableRoot.scrollTo(0, scrollPositions.get(to.url.pathname) || 0);\\n    } else {\\n      scrollPositions.delete(to.url.pathname);\\n    }\\n  } else {\\n    scrollableRoot.scrollTo(0, 0);\\n  }\\n});\\nonMount(async () => {\\n  ui();\\n  scrollableRoot = document.querySelector(\\".root\\");\\n  loadSettingsFromEnv();\\n  bookmarkletLoadFromUrl();\\n  let themeHex = get(themeColorStore);\\n  if (themeHex) {\\n    await ui(\\"theme\\", themeHex);\\n  } else if (Capacitor.getPlatform() === \\"android\\") {\\n    if (!themeHex) {\\n      try {\\n        const colorPalette = await colorTheme.getColorPalette();\\n        themeHex = convertToHexColorCode(colorPalette.primary);\\n        await ui(\\"theme\\", themeHex);\\n      } catch {\\n      }\\n    }\\n  }\\n  await setStatusBarColor();\\n  setTheme();\\n  setAmoledTheme();\\n  if (isLoggedIn) {\\n    loadNotifications().catch(() => authStore.set(null));\\n  }\\n});\\n$: webManifestLink = pwaInfo ? pwaInfo.webManifest.linkTag : \\"\\";\\n<\/script>\\n\\n<svelte:head>\\n\\t{@html webManifestLink}\\n</svelte:head>\\n\\n<nav class=\\"left m l small\\">\\n\\t<header></header>\\n\\t{#each getPages() as page}\\n\\t\\t{#if !page.requiresAuth || isLoggedIn}\\n\\t\\t\\t<a href={page.href} class:active={currentPage === page.name.toLowerCase()}\\n\\t\\t\\t\\t><i>{page.icon}</i>\\n\\t\\t\\t\\t<div>{page.name}</div>\\n\\t\\t\\t</a>\\n\\t\\t{/if}\\n\\t{/each}\\n</nav>\\n\\n<nav class=\\"top\\">\\n\\t{#if !mobileSearchShow}\\n\\t\\t<button\\n\\t\\t\\ton:click={() => (mobileSearchShow = !mobileSearchShow)}\\n\\t\\t\\tclass=\\"transparent s circle large\\"\\n\\t\\t>\\n\\t\\t\\t<i>search</i>\\n\\t\\t</button>\\n\\t{/if}\\n\\n\\t{#if Capacitor.getPlatform() === 'electron'}\\n\\t\\t<nav class=\\"no-space\\">\\n\\t\\t\\t<button on:click={() => window.history.back()} class=\\"border left-round\\">\\n\\t\\t\\t\\t<i>arrow_back</i>\\n\\t\\t\\t</button>\\n\\t\\t\\t<button on:click={() => window.history.forward()} class=\\"border right-round\\">\\n\\t\\t\\t\\t<i>arrow_forward</i>\\n\\t\\t\\t</button>\\n\\t\\t</nav>\\n\\t{/if}\\n\\n\\t<nav on:click={() => goto('/')} style=\\"cursor: pointer;\\" class=\\"m l\\">\\n\\t\\t<Logo />\\n\\t\\t<h6 class=\\"l\\">Materialious</h6>\\n\\t</nav>\\n\\n\\t<div class=\\"max m l\\"></div>\\n\\n\\t<div class=\\"m l\\">\\n\\t\\t<Search />\\n\\t</div>\\n\\n\\t{#if !mobileSearchShow}\\n\\t\\t<div class=\\"max\\"></div>\\n\\t{/if}\\n\\n\\t{#if mobileSearchShow}\\n\\t\\t<Search on:searchCancelled={() => (mobileSearchShow = false)} />\\n\\t{:else}\\n\\t\\t{#if !Capacitor.isNativePlatform()}\\n\\t\\t\\t<button data-ui=\\"#sync-party\\" class=\\"circle large transparent\\">\\n\\t\\t\\t\\t<i class:primary-text={$syncPartyPeerStore}>group</i>\\n\\t\\t\\t\\t<div class=\\"tooltip bottom\\">{$_('layout.syncParty')}</div>\\n\\t\\t\\t</button>\\n\\t\\t{/if}\\n\\t\\t{#if isLoggedIn}\\n\\t\\t\\t<button class=\\"circle large transparent\\" on:click={() => ui('#dialog-notifications')}\\n\\t\\t\\t\\t><i>notifications</i>\\n\\t\\t\\t\\t<div class=\\"tooltip bottom\\">{$_('layout.notifications')}</div>\\n\\t\\t\\t</button>\\n\\t\\t{/if}\\n\\t\\t<button class=\\"circle large transparent\\" on:click={() => ui('#dialog-settings')}>\\n\\t\\t\\t<i>settings</i>\\n\\t\\t\\t<div class=\\"tooltip bottom\\">{$_('layout.settings')}</div>\\n\\t\\t</button>\\n\\n\\t\\t{#if !isLoggedIn}\\n\\t\\t\\t<button on:click={login} class=\\"circle large transparent\\">\\n\\t\\t\\t\\t<i>login</i>\\n\\t\\t\\t\\t<div class=\\"tooltip bottom\\">{$_('layout.login')}</div>\\n\\t\\t\\t</button>\\n\\t\\t{:else}\\n\\t\\t\\t<button on:click={logout} class=\\"circle large transparent\\">\\n\\t\\t\\t\\t<i>logout</i>\\n\\t\\t\\t\\t<div class=\\"tooltip bottom\\">{$_('layout.logout')}</div>\\n\\t\\t\\t</button>\\n\\t\\t{/if}\\n\\t{/if}\\n</nav>\\n\\n<nav class=\\"bottom s\\">\\n\\t{#each getPages() as page}\\n\\t\\t{#if !page.requiresAuth || isLoggedIn}\\n\\t\\t\\t<a class=\\"round\\" href={page.href} class:active={currentPage === page.name.toLowerCase()}\\n\\t\\t\\t\\t><i>{page.icon}</i>\\n\\t\\t\\t\\t{#if currentPage === page.name.toLowerCase()}\\n\\t\\t\\t\\t\\t<span style=\\"font-size: .8em;\\">{page.name}</span>\\n\\t\\t\\t\\t{/if}\\n\\t\\t\\t</a>\\n\\t\\t{/if}\\n\\t{/each}\\n</nav>\\n\\n<Settings />\\n\\n<dialog class=\\"right\\" id=\\"dialog-notifications\\">\\n\\t<nav>\\n\\t\\t<h5 class=\\"max\\">{$_('layout.notifications')}</h5>\\n\\t\\t<button class=\\"circle transparent\\" data-ui=\\"#dialog-notifications\\"><i>close</i></button>\\n\\t</nav>\\n\\t{#if notifications.length === 0}\\n\\t\\t<p>{$_('layout.noNewNotifications')}</p>\\n\\t{:else}\\n\\t\\t{#each notifications as notification}\\n\\t\\t\\t<article class=\\"no-padding\\">\\n\\t\\t\\t\\t<Thumbnail video={notification}></Thumbnail>\\n\\t\\t\\t</article>\\n\\t\\t{/each}\\n\\t{/if}\\n</dialog>\\n\\n<main class=\\"responsive max root\\">\\n\\t{#if Capacitor.getPlatform() === 'web' && $showWarningStore}\\n\\t\\t<dialog class=\\"active small\\" style=\\"height: fit-content;\\">\\n\\t\\t\\t<h5>Warning</h5>\\n\\t\\t\\t<div>\\n\\t\\t\\t\\t<p>\\n\\t\\t\\t\\t\\t{@html $_('invidiousBlockWarning', {\\n\\t\\t\\t\\t\\t\\tvalues: {\\n\\t\\t\\t\\t\\t\\t\\tandroid:\\n\\t\\t\\t\\t\\t\\t\\t\\t'<a href=\\"https://github.com/Materialious/Materialious?tab=readme-ov-file#android\\" target=\\"_blank\\" class=\\"link\\" rel=\\"noopener noreferrer\\">Android</a>',\\n\\t\\t\\t\\t\\t\\t\\tdesktop:\\n\\t\\t\\t\\t\\t\\t\\t\\t'<a href=\\"https://github.com/Materialious/Materialious?tab=readme-ov-file#desktop-windowsmacoslinux\\" target=\\"_blank\\" class=\\"link\\" rel=\\"noopener noreferrer\\">Desktop</a>'\\n\\t\\t\\t\\t\\t\\t}\\n\\t\\t\\t\\t\\t})}\\n\\t\\t\\t\\t</p>\\n\\t\\t\\t</div>\\n\\t\\t\\t<nav class=\\"right-align no-space\\">\\n\\t\\t\\t\\t<button class=\\"transparent link\\" on:click={() => showWarningStore.set(false)}\\n\\t\\t\\t\\t\\t>Don't show again</button\\n\\t\\t\\t\\t>\\n\\t\\t\\t</nav>\\n\\t\\t</dialog>\\n\\t{/if}\\n\\t{#if $navigating}\\n\\t\\t<PageLoading />\\n\\t{:else}\\n\\t\\t<slot />\\n\\t{/if}\\n\\n\\t<SyncParty />\\n\\t<MiniPlayer />\\n</main>\\n\\n<style>\\n\\tnav.left a {\\n\\t\\tfont-size: 0.8em;\\n\\t}\\n</style>\\n"],"names":[],"mappings":"AAwSC,GAAG,oBAAK,CAAC,gBAAE,CACV,SAAS,CAAE,KACZ"}`
};
const Layout = create_ssr_component(($$result, $$props, $$bindings, slots) => {
  let webManifestLink;
  let $syncPartyPeerStore, $$unsubscribe_syncPartyPeerStore;
  let $_, $$unsubscribe__;
  let $showWarningStore, $$unsubscribe_showWarningStore;
  let $navigating, $$unsubscribe_navigating;
  $$unsubscribe_syncPartyPeerStore = subscribe(syncPartyPeerStore, (value) => $syncPartyPeerStore = value);
  $$unsubscribe__ = subscribe($format, (value) => $_ = value);
  $$unsubscribe_showWarningStore = subscribe(showWarningStore, (value) => $showWarningStore = value);
  $$unsubscribe_navigating = subscribe(navigating, (value) => $navigating = value);
  let currentPage = "";
  activePageStore.subscribe((page2) => currentPage = page2);
  let isLoggedIn = false;
  authStore.subscribe((value) => {
    isLoggedIn = value !== null;
  });
  let notifications = [];
  interfaceAmoledTheme.subscribe(async () => {
    setAmoledTheme();
    await setStatusBarColor();
  });
  darkModeStore.subscribe(async () => {
    setTheme();
    setAmoledTheme();
    await setStatusBarColor();
  });
  App.addListener("appUrlOpen", (data) => {
    const url = new URL(data.url);
    if (url.protocol !== "materialious-auth:") {
      let videoId = url.searchParams.get("v");
      if (!videoId) {
        videoId = url.pathname.split("/")[1];
      }
      if (!videoId) {
        return;
      }
      goto();
    } else {
      const username = url.searchParams.get("username");
      const token = url.searchParams.get("token");
      if (username && token) {
        authStore.set({ username, token });
      }
    }
  });
  $$result.css.add(css);
  webManifestLink = pwaInfo ? pwaInfo.webManifest.linkTag : "";
  $$unsubscribe_syncPartyPeerStore();
  $$unsubscribe__();
  $$unsubscribe_showWarningStore();
  $$unsubscribe_navigating();
  return `${$$result.head += `<!-- HEAD_svelte-1pmpekp_START --><!-- HTML_TAG_START -->${webManifestLink}<!-- HTML_TAG_END --><!-- HEAD_svelte-1pmpekp_END -->`, ""} <nav class="left m l small svelte-16bpv4m"><header></header> ${each(getPages(), (page2) => {
    return `${!page2.requiresAuth || isLoggedIn ? `<a${add_attribute("href", page2.href, 0)} class="${["svelte-16bpv4m", currentPage === page2.name.toLowerCase() ? "active" : ""].join(" ").trim()}"><i>${escape(page2.icon)}</i> <div>${escape(page2.name)}</div> </a>` : ``}`;
  })}</nav> <nav class="top">${`<button class="transparent s circle large" data-svelte-h="svelte-ubmk60"><i>search</i></button>`} ${Capacitor.getPlatform() === "electron" ? `<nav class="no-space"><button class="border left-round" data-svelte-h="svelte-4iy01k"><i>arrow_back</i></button> <button class="border right-round" data-svelte-h="svelte-a11cc1"><i>arrow_forward</i></button></nav>` : ``} <nav style="cursor: pointer;" class="m l">${validate_component(Logo, "Logo").$$render($$result, {}, {}, {})} <h6 class="l" data-svelte-h="svelte-1o8qq1k">Materialious</h6></nav> <div class="max m l"></div> <div class="m l">${validate_component(Search, "Search").$$render($$result, {}, {}, {})}</div> ${`<div class="max"></div>`} ${`${!Capacitor.isNativePlatform() ? `<button data-ui="#sync-party" class="circle large transparent"><i${add_classes(($syncPartyPeerStore ? "primary-text" : "").trim())} data-svelte-h="svelte-1avivku">group</i> <div class="tooltip bottom">${escape($_("layout.syncParty"))}</div></button>` : ``} ${isLoggedIn ? `<button class="circle large transparent"><i data-svelte-h="svelte-1a0i7ji">notifications</i> <div class="tooltip bottom">${escape($_("layout.notifications"))}</div></button>` : ``} <button class="circle large transparent"><i data-svelte-h="svelte-1vh8pnb">settings</i> <div class="tooltip bottom">${escape($_("layout.settings"))}</div></button> ${!isLoggedIn ? `<button class="circle large transparent"><i data-svelte-h="svelte-11ry0gz">login</i> <div class="tooltip bottom">${escape($_("layout.login"))}</div></button>` : `<button class="circle large transparent"><i data-svelte-h="svelte-cpu96a">logout</i> <div class="tooltip bottom">${escape($_("layout.logout"))}</div></button>`}`}</nav> <nav class="bottom s">${each(getPages(), (page2) => {
    return `${!page2.requiresAuth || isLoggedIn ? `<a class="${["round", currentPage === page2.name.toLowerCase() ? "active" : ""].join(" ").trim()}"${add_attribute("href", page2.href, 0)}><i>${escape(page2.icon)}</i> ${currentPage === page2.name.toLowerCase() ? `<span style="font-size: .8em;">${escape(page2.name)}</span>` : ``} </a>` : ``}`;
  })}</nav> ${validate_component(Settings, "Settings").$$render($$result, {}, {}, {})} <dialog class="right" id="dialog-notifications"><nav><h5 class="max">${escape($_("layout.notifications"))}</h5> <button class="circle transparent" data-ui="#dialog-notifications" data-svelte-h="svelte-13irm5m"><i>close</i></button></nav> ${notifications.length === 0 ? `<p>${escape($_("layout.noNewNotifications"))}</p>` : `${each(notifications, (notification) => {
    return `<article class="no-padding">${validate_component(Thumbnail, "Thumbnail").$$render($$result, { video: notification }, {}, {})} </article>`;
  })}`}</dialog> <main class="responsive max root">${Capacitor.getPlatform() === "web" && $showWarningStore ? `<dialog class="active small" style="height: fit-content;"><h5 data-svelte-h="svelte-17xgmwu">Warning</h5> <div><p><!-- HTML_TAG_START -->${$_("invidiousBlockWarning", {
    values: {
      android: '<a href="https://github.com/Materialious/Materialious?tab=readme-ov-file#android" target="_blank" class="link" rel="noopener noreferrer">Android</a>',
      desktop: '<a href="https://github.com/Materialious/Materialious?tab=readme-ov-file#desktop-windowsmacoslinux" target="_blank" class="link" rel="noopener noreferrer">Desktop</a>'
    }
  })}<!-- HTML_TAG_END --></p></div> <nav class="right-align no-space"><button class="transparent link" data-svelte-h="svelte-9f6bt9">Don&#39;t show again</button></nav></dialog>` : ``} ${$navigating ? `${validate_component(PageLoading, "PageLoading").$$render($$result, {}, {}, {})}` : `${slots.default ? slots.default({}) : ``}`} ${validate_component(SyncParty, "SyncParty").$$render($$result, {}, {}, {})} ${validate_component(MiniPlayer, "MiniPlayer").$$render($$result, {}, {}, {})} </main>`;
});
export {
  Layout as default
};
