import { j as getVideo, l as getComments, m as amSubscribed, p as postHistory, d as getPersonalPlaylists, n as getDislikes } from "../../../../../chunks/index.js";
import { p as playerProxyVideosStore, b as authStore, r as returnYTDislikesInstanceStore, j as returnYtDislikesStore } from "../../../../../chunks/store.js";
import { d as decodeHtmlCharCodes } from "../../../../../chunks/misc.js";
import { a as convertToSeconds } from "../../../../../chunks/time.js";
import { e as error } from "../../../../../chunks/index2.js";
import { g as get_store_value } from "../../../../../chunks/utils.js";
function phaseDescription(content, usingYoutubeJs = false) {
  const timestamps = [];
  const lines = content.split("\n");
  const urlRegex = /<a href="([^"]+)"/;
  const timestampRegexInvidious = /<a href="([^"]+)" data-onclick="jump_to_time" data-jump-time="(\d+)">(\d+:\d+(?::\d+)?)<\/a>\s*(.+)/;
  const timestampRegexYtJs = /&(?:\S*?&)?t=(\d+)\s*s.*?<span[^>]*>([^<]*)<\/span>.*?>(.*?)<\/span>/;
  let filteredLines = [];
  lines.forEach((line) => {
    const urlMatch = urlRegex.exec(line);
    const timestampMatch = (usingYoutubeJs ? timestampRegexYtJs : timestampRegexInvidious).exec(usingYoutubeJs ? line + "</span>" : line);
    if (urlMatch !== null && timestampMatch === null) {
      const modifiedLine = line.replace(
        /<a href="([^"]+)"/,
        '<a href="$1" target="_blank" rel="noopener noreferrer" class="link"'
      );
      filteredLines.push(modifiedLine);
    } else if (timestampMatch !== null) {
      const time = usingYoutubeJs ? timestampMatch[1] : timestampMatch[2];
      const timestamp = usingYoutubeJs ? timestampMatch[2] : timestampMatch[3];
      const title = usingYoutubeJs ? timestampMatch[3] || "" : timestampMatch[4] || "";
      timestamps.push({
        time: convertToSeconds(time),
        // Remove any HTML in the timestamp title.
        title: decodeHtmlCharCodes(title.replace(/<[^>]+>/g, "").replace(/\n/g, "").trim()),
        timePretty: timestamp
      });
    } else {
      filteredLines.push(line);
    }
  });
  const filteredContent = filteredLines.join("\n");
  return { description: filteredContent, timestamps };
}
async function load({ params, url }) {
  let video;
  try {
    video = await getVideo(params.slug, get_store_value(playerProxyVideosStore), { priority: "high" });
  } catch (errorMessage) {
    error(500, errorMessage);
  }
  let personalPlaylists;
  if (get_store_value(authStore)) {
    postHistory(video.videoId);
    personalPlaylists = getPersonalPlaylists({ priority: "low" });
  } else {
    personalPlaylists = null;
  }
  let comments;
  try {
    comments = video.liveNow ? null : getComments(params.slug, { sort_by: "top", source: "youtube" }, { priority: "low" });
  } catch {
    comments = null;
  }
  let returnYTDislikes;
  const returnYTDislikesInstance = get_store_value(returnYTDislikesInstanceStore);
  if (returnYTDislikesInstance && returnYTDislikesInstance !== "") {
    try {
      returnYTDislikes = get_store_value(returnYtDislikesStore) ? getDislikes(params.slug, { priority: "low" }) : null;
    } catch {
    }
  }
  return {
    video,
    content: phaseDescription(video.descriptionHtml, video.fallbackPatch === "youtubejs"),
    playlistId: url.searchParams.get("playlist"),
    streamed: {
      personalPlaylists,
      returnYTDislikes,
      comments,
      subscribed: amSubscribed(video.authorId)
    }
  };
}
export {
  load
};
